<?php
/**
 * The plugin elementor addons.
 *
 * @link       https://shapedplugin.com/
 * @since      2.1.4
 *
 * @package    WP_Tabs_Pro
 * @subpackage WP_Tabs_Pro/admin
 * @author     ShapedPlugin <support@shapedplugin.com>
 */

/**
 * Elementor shortcode addon.
 */
class WP_Tabs_Pro_Elementor_Addons {
	/**
	 * Script and Style suffix
	 *
	 * @since 2.1.4
	 * @access protected
	 * @var string
	 */
	protected $min;

	/**
	 * Instance
	 *
	 * @since 2.1.4
	 *
	 * @access private
	 * @static
	 *
	 * @var WP_Tabs_Pro_Elementor_Addons The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 2.1.4
	 *
	 * @access public
	 * @static
	 *
	 * @return Elementor_Test_Extension An instance of the class.
	 */
	public static function instance() {

		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;

	}

	/**
	 * Constructor
	 *
	 * @since 2.1.4
	 *
	 * @access public
	 */
	public function __construct() {
		$this->on_plugins_loaded();
		add_action( 'elementor/preview/enqueue_scripts', array( $this, 'wp_tabs_pro_enqueue_scripts' ) );
		add_action( 'elementor/preview/enqueue_styles', array( $this, 'wp_tabs_pro_enqueue_styles' ) );
		add_action( 'elementor/editor/before_enqueue_scripts', array( $this, 'wp_tabs_pro_addons_icon' ) );
	}

	/**
	 * Enqueue CSS for the ElementOr edit page.
	 *
	 * @since    2.1.4
	 */
	public function wp_tabs_pro_enqueue_styles() {
		/**
		 * Register block editor CSS file enqueue for backend.
		 */
		wp_enqueue_style( 'sptpro-font-awesome' );
		wp_enqueue_style( 'sptpro-accordion-style' );
		wp_enqueue_style( 'sptpro-animate-css' );
		wp_enqueue_style( 'sptpro-tab-carousel-style' );
		wp_enqueue_style( 'sptpro-tab-carousel-theme-style' );
		wp_enqueue_style( 'sptpro-style' );
	}
	/**
	 * Enqueue the JavaScript for the ElementOr block area.
	 *
	 * @since    2.1.4
	 */
	public function wp_tabs_pro_enqueue_scripts() {
		/**
		 * Register block editor CSS file enqueue for elemantor edit page.
		 */
		wp_enqueue_script( 'sptpro-tab' );
		wp_enqueue_script( 'sptpro-collapse' );
		wp_enqueue_script( 'sptpro-smooth-scrollbar' );
		wp_enqueue_script( 'sptpro-match-height' );
		wp_enqueue_script( 'sptpro-tab-carousel-script' );
		wp_enqueue_script( 'sptpro-script' );
	}

	/**
	 * Elementor block icon.
	 *
	 * @since    2.1.4
	 * @return void
	 */
	public function wp_tabs_pro_addons_icon() {
		wp_enqueue_style( 'wp_tabs_pro-elementor-addons-icon', WP_TABS_PRO_URL . 'admin/css/tabs-pro-elementor-icon.min.css', array(), WP_TABS_PRO_VERSION, 'all' );
	}

	/**
	 * On Plugins Loaded
	 *
	 * Checks if Elementor has loaded, and performs some compatibility checks.
	 * If All checks pass, inits the plugin.
	 *
	 * Fired by `plugins_loaded` action hook.
	 *
	 * @since 2.1.4
	 *
	 * @access public
	 */
	public function on_plugins_loaded() {
		add_action( 'elementor/init', array( $this, 'init' ) );
	}

	/**
	 * Initialize the plugin
	 *
	 * Load the plugin only after Elementor (and other plugins) are loaded.
	 * Load the files required to run the plugin.
	 *
	 * Fired by `plugins_loaded` action hook.
	 *
	 * @since 2.1.4
	 *
	 * @access public
	 */
	public function init() {
		// Add Plugin actions.
		add_action( 'elementor/widgets/register', array( $this, 'init_widgets' ) );
	}

	/**
	 * Init Widgets
	 *
	 * Include widgets files and register them
	 *
	 * @since 2.1.4
	 *
	 * @access public
	 */
	public function init_widgets() {
		// Register widget.
		require_once __DIR__ . '/widgets/shortcode.php';
		\Elementor\Plugin::instance()->widgets_manager->register( new WP_Tabs_Pro_Eelementor_Shortcode_Widget() );

	}

}
WP_Tabs_Pro_Elementor_Addons::instance();
