<?php
/**
 * The plugin elementor shortcode Widget.
 *
 * @link       https://shapedplugin.com/
 * @since      2.1.4
 *
 * @package    WP_Tabs_Pro
 * @subpackage WP_Tabs_Pro/admin
 * @author     ShapedPlugin <support@shapedplugin.com>
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor List Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 2.1.4
 */
class WP_Tabs_Pro_Eelementor_Shortcode_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve list widget name.
	 *
	 * @since 2.1.4
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'sp-wp-tabs-shortcode-ew';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve list widget title.
	 *
	 * @since 2.1.4
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'WP Tabs Pro', 'wp-tabs-pro' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve list widget icon.
	 *
	 * @since 2.1.4
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'wp_tabs_pro-elementor-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the list widget belongs to.
	 *
	 * @since 2.1.4
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'basic' );
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the list widget belongs to.
	 *
	 * @since 2.1.4
	 * @access public
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return array( 'shortcode', 'wp tabs', 'tabs' );
	}

	/**
	 * Get all post list.
	 *
	 * @since 2.1.4
	 * @return array
	 */
	public function sp_wp_tabs_post_list() {
		$post_list    = array();
		$sp_eap_posts = new \WP_Query(
			array(
				'post_type'      => 'sp_wp_tabs',
				'post_status'    => 'publish',
				'posts_per_page' => 10000,
			)
		);
		$posts        = $sp_eap_posts->posts;
		foreach ( $posts as $post ) {
			$post_list[ $post->ID ] = $post->post_title;
		}
		krsort( $post_list );
		return $post_list;
	}

	/**
	 * Register list widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.
	 *
	 * @since 2.1.4
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => __( 'Content', 'wp-tabs-pro' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'sp_wp_tabs_shortcode',
			array(
				'label'       => __( 'WP Tabs Shortcode(s)', 'wp-tabs-pro' ),
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'label_block' => true,
				'default'     => '',
				'options'     => $this->sp_wp_tabs_post_list(),
			)
		);

		$this->end_controls_section();

	}

	/**
	 * Render list widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 2.1.4
	 * @access protected
	 */
	protected function render() {
		$settings             = $this->get_settings_for_display();
		$sp_wp_tabs_shortcode = $settings['sp_wp_tabs_shortcode'];

		if ( '' === $sp_wp_tabs_shortcode ) {
			echo '<div style="text-align: center; margin-top: 0; padding: 10px" class="elementor-add-section-drag-title">Select a shortcode</div>';
			return;
		}

		$post_id = (int) $sp_wp_tabs_shortcode;
		if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) {
			// Content Accordion.
			$sptpro_data_upload       = get_post_meta( $post_id, 'sp_tab_source_options', true );
			$sptpro_shortcode_options = get_post_meta( $post_id, 'sp_tab_shortcode_options', true );
			$main_section_title       = get_the_title( $post_id );

			// Stylesheet loading problem solving here. Shortcode id to push page id option for getting how many shortcode in the page.
			$current_page_id    = get_queried_object_id();
			$option_key         = 'sp_tabs_page_id' . $current_page_id;
			$found_generator_id = get_option( $option_key );
			if ( is_multisite() ) {
				$option_key         = 'sp_tabs_page_id' . get_current_blog_id() . $current_page_id;
				$found_generator_id = get_site_option( $option_key );
			}
			// This shortcode id not in page id option. Enqueue stylesheets in shortcode.
			if ( ! is_array( $found_generator_id ) || ! $found_generator_id || ! in_array( $post_id, $found_generator_id ) ) {
				$sptpro_dynamic_style = '';
				$sptpro_typography    = array();
				include WP_TABS_PRO_PATH . 'public/dynamic_style.php';
				if ( $sptpro_dequeue_google_font ) {
					$enqueue_fonts = WP_Tabs_Pro_Public::load_google_fonts( $sptpro_typography );
					if ( ! empty( $enqueue_fonts ) ) {
						echo '<link rel="stylesheet" href="' . esc_url( add_query_arg( 'family', rawurlencode( implode( '|', $enqueue_fonts ) ), '//fonts.googleapis.com/css' ) ) . '" media="all">';
					}
				}
				// Custom CSS loads.
				$sp_tab_settings       = get_option( 'sp-tab__settings' );
				$custom_style          = isset( $sp_tab_settings['sptpro_custom_css'] ) ? trim( html_entity_decode( $sp_tab_settings['sptpro_custom_css'] ) ) : '';
				$sptpro_dynamic_style .= $custom_style;
				$dynamic_style         = WP_Tabs_Pro_Public::minify_output( $sptpro_dynamic_style );

				echo '<style id="sp_tabs_elemintor_dynamic_style' . esc_attr( $post_id ) . ' ">' . $dynamic_style . '</style>';
			}

			WP_Tabs_Pro_Shortcode::sp_tab_html_show( $post_id, $sptpro_data_upload, $sptpro_shortcode_options, $main_section_title );
			?>
			<script src=" <?php echo esc_url( WP_TABS_PRO_URL . 'public/js/wp-tabs-pro-public.min.js' ); ?>" ></script>
			<?php
		} else {
			echo do_shortcode( '[wptabs id="' . $post_id . '"]' );
		}
	}

}
