<?php
/**
 * The plugin gutenberg block Initializer.
 *
 * @link       https://shapedplugin.com/
 * @since      2.1.3
 *
 * @package    WP_Tabs_Pro
 * @subpackage WP_Tabs_Pro/Admin
 * @author     ShapedPlugin <support@shapedplugin.com>
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WP_Tabs_Pro_Gutenberg_Block_Init' ) ) {
	/**
	 * WP_Tabs_Pro_Gutenberg_Block_Init class.
	 */
	class WP_Tabs_Pro_Gutenberg_Block_Init {
		/**
		 * Script and style suffix
		 *
		 * @since 2.1.3
		 * @access protected
		 * @var string
		 */
		protected $min;

		/**
		 * Custom Gutenberg Block Initializer.
		 */
		public function __construct() {
			$this->min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG || defined( 'WP_DEBUG' ) && WP_DEBUG ? '' : '.min';
			add_action( 'init', array( $this, 'sp_tabs_gutenberg_shortcode_block' ) );
			add_action( 'enqueue_block_editor_assets', array( $this, 'sp_tabs_block_editor_assets' ) );
		}

		/**
		 * Register block editor script for backend.
		 */
		public function sp_tabs_block_editor_assets() {
			wp_enqueue_script(
				'wp-tabs-pro-shortcode-block',
				plugins_url( '/GutenbergBlock/build/index.js', dirname( __FILE__ ) ),
				array( 'jquery' ),
				WP_TABS_PRO_VERSION,
				true
			);

			/**
			 * Register block editor css file enqueue for backend.
			 */
			wp_enqueue_style( 'sptpro-font-awesome' );
			wp_enqueue_style( 'sptpro-accordion-style' );
			wp_enqueue_style( 'sptpro-animate-css' );
			wp_enqueue_style( 'sptpro-tab-carousel-style' );
			wp_enqueue_style( 'sptpro-tab-carousel-theme-style' );
			wp_enqueue_style( 'sptpro-style' );

		}
		/**
		 * Shortcode list.
		 *
		 * @return array
		 */
		public function tabs_post_list() {
			$shortcodes = get_posts(
				array(
					'post_type'      => 'sp_wp_tabs',
					'post_status'    => 'publish',
					'posts_per_page' => 9999,
				)
			);

			if ( count( $shortcodes ) < 1 ) {
				return array();
			}

			return array_map(
				function ( $shortcode ) {
						return (object) array(
							'id'    => absint( $shortcode->ID ),
							'title' => esc_html( $shortcode->post_title ),
						);
				},
				$shortcodes
			);
		}

		/**
		 * Register Gutenberg shortcode block.
		 */
		public function sp_tabs_gutenberg_shortcode_block() {
			/**
			 * Register block editor js file enqueue for backend.
			 */
			wp_register_script( 'sptpro-gb-script', WP_TABS_PRO_URL . 'public/js/wp-tabs-pro-public' . $this->min . '.js', array( 'jquery' ), WP_TABS_PRO_VERSION, true );
			wp_localize_script(
				'sptpro-gb-script',
				'sp_tab_pro_gb_block',
				array(
					'url'           => WP_TABS_PRO_URL,
					'loadPublic'    => WP_TABS_PRO_URL . 'public/js/wp-tabs-pro-public.min.js',
					'link'          => admin_url( 'post-new.php?post_type=sp_wp_tabs' ),
					'shortCodeList' => $this->tabs_post_list(),
				)
			);
			/**
			 * Register Gutenberg block on server-side.
			 */
			register_block_type(
				'sp-wp-tabs-pro/shortcode',
				array(
					'attributes'      => array(
						'shortcode'          => array(
							'type'    => 'object',
							'default' => '',
						),
						'shortcode'          => array(
							'type'    => 'string',
							'default' => '',
						),
						'showInputShortcode' => array(
							'type'    => 'boolean',
							'default' => true,
						),
						'preview'            => array(
							'type'    => 'boolean',
							'default' => false,
						),
						'is_admin'           => array(
							'type'    => 'boolean',
							'default' => is_admin(),
						),
					),
					'example'         => array(
						'attributes' => array(
							'preview' => true,
						),
					),
					// Enqueue blocks.editor.build.js in the editor only.
					'editor_script'   => array(
						'sptpro-tab',
						'sptpro-collapse',
						'sptpro-smooth-scrollbar',
						'sptpro-match-height',
						'sptpro-gb-script',
						'sptpro-tab-carousel-script',
					),
					// Enqueue blocks.editor.build.css in the editor only.
					'editor_style'    => array(),
					'render_callback' => array( $this, 'wp_tabs_pro_render_shortcode' ),
				)
			);
		}

		/**
		 * Render callback.
		 *
		 * @param string $attributes Shortcode.
		 * @return string
		 */
		public function wp_tabs_pro_render_shortcode( $attributes ) {

			$class_name = '';
			if ( ! empty( $attributes['className'] ) ) {
				$class_name = 'class="' . esc_attr( $attributes['className'] ) . '"';
			}
			if ( ! $attributes['is_admin'] ) {
				return '<div ' . $class_name . '>' . do_shortcode( '[wptabs id="' . sanitize_text_field( $attributes['shortcode'] ) . '"]' ) . '</div>';
			}
			$post_id                  = esc_attr( (int) $attributes['shortcode'] );
			$sptpro_data_upload       = get_post_meta( $post_id, 'sp_tab_source_options', true );
			$sptpro_shortcode_options = get_post_meta( $post_id, 'sp_tab_shortcode_options', true );
			$main_section_title       = get_the_title( $post_id );
			$sptpro_dynamic_style     = '';
			$sptpro_typography        = array();
			$style                    = '';
			include WP_TABS_PRO_PATH . 'public/dynamic_style.php';

			if ( $sptpro_dequeue_google_font ) {
				$enqueue_fonts = WP_Tabs_Pro_Public::load_google_fonts( $sptpro_typography );
				if ( ! empty( $enqueue_fonts ) ) {
					$style .= '<link rel="stylesheet" href="' . esc_url( add_query_arg( 'family', rawurlencode( implode( '|', $enqueue_fonts ) ), '//fonts.googleapis.com/css' ) ) . '" media="all">';
				}
			}
			// Custom CSS loads.
			$settings              = get_option( 'sp-tab__settings' );
			$custom_style          = isset( $settings['sptpro_custom_css'] ) ? trim( html_entity_decode( $settings['sptpro_custom_css'] ) ) : '';
			$sptpro_dynamic_style .= $custom_style;
			$dynamic_style         = WP_Tabs_Pro_Public::minify_output( $sptpro_dynamic_style );
			$style                .= '<style id="sp_tabs_gb_dynamic_style' . esc_attr( $post_id ) . ' ">' . $dynamic_style . '</style>';

			$edit_page_link = get_edit_post_link( sanitize_text_field( $attributes['shortcode'] ) );
			return $style . '<div id="' . uniqid() . '" ' . $class_name . ' ><a href="' . esc_url( $edit_page_link ) . '" target="_blank" class="sp_testimonial_block_edit_button">Edit Tab Group</a>' . do_shortcode( '[wptabs id="' . sanitize_text_field( $attributes['shortcode'] ) . '"]' ) . '</div>';
		}
	}
}
