<?php
/**
 * The metabox fields of the plugin.
 *
 * @link       https://shapedplugin.com/
 * @since      1.0.0
 *
 * @package    WP_Tabs_Pro
 * @subpackage WP_Tabs_Pro/admin
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
} // Cannot access pages directly.

//
// Metabox of the content source settings section.
// Set a unique slug-like ID.
//
$sptpro_content_source_settings = 'sp_tab_source_options';

/**
 * Preview metabox.
 *
 * @param string $prefix The metabox main Key.
 * @return void
 */
SP_WP_TABS::createMetabox(
	'sp_tab_live_preview',
	array(
		'title'        => __( 'Live Preview', 'wp-tabs-pro' ),
		'post_type'    => 'sp_wp_tabs',
		'show_restore' => false,
		'context'      => 'normal',
	)
);
SP_WP_TABS::createSection(
	'sp_tab_live_preview',
	array(
		'fields' => array(
			array(
				'type' => 'preview',
			),
		),
	)
);

//
// Create a metabox for content source settings.
//
SP_WP_TABS::createMetabox(
	$sptpro_content_source_settings,
	array(
		'title'     => __( 'WP Tabs Pro', 'wp-tabs-pro' ),
		'post_type' => 'sp_wp_tabs',
		'context'   => 'normal',
	)
);

//
// Create a section for content source settings.
//
SP_WP_TABS::createSection(
	$sptpro_content_source_settings,
	array(
		'fields' => array(
			array(
				'type'  => 'heading',
				'image' => plugin_dir_url( __DIR__ ) . 'partials/img/wp-tabs-logo.svg',
				'after' => '<i class="fa fa-life-ring"></i> Support',
				'link'  => 'https://shapedplugin.com/support/',
				'class' => 'sp-tab__admin-header',
			),
			array(
				'id'      => 'sptpro_tab_type',
				'type'    => 'button_set',
				'class'   => 'sp-tab__content_wrapper',
				'title'   => __( 'Tabs Type', 'wp-tabs-pro' ),
				'options' => array(
					'content-tabs' => __( 'Content', 'wp-tabs-pro' ),
					'post-tabs'    => __( 'Post', 'wp-tabs-pro' ),
				),
				'default' => 'content-tabs',
			),
			// Content Tabs.
			array(
				'id'                     => 'sptpro_content_source',
				'type'                   => 'group',
				'title'                  => __( 'Tabs Content', 'wp-tabs-pro' ),
				'button_title'           => __( 'Add New Tab', 'wp-tabs-pro' ),
				'class'                  => 'sp-tab__content_wrapper',
				'accordion_title_prefix' => __( 'Item :', 'wp-tabs-pro' ),
				'accordion_title_number' => true,
				'accordion_title_auto'   => true,
				'fields'                 => array(
					array(
						'id'         => 'tabs_content_title',
						'type'       => 'text',
						'wrap_class' => 'sp-tab__content_source',
						'title'      => __( 'Title', 'wp-tabs-pro' ),
					),
					array(
						'id'         => 'tabs_content_subtitle',
						'type'       => 'text',
						'wrap_class' => 'sp-tab__content_source',
						'title'      => __( 'Subtitle (Optional)', 'wp-tabs-pro' ),
					),
					array(
						'id'           => 'tabs_content_icon',
						'type'         => 'icon',
						'wrap_class'   => 'sp-tab__content_source',
						'button_title' => __( 'Font Icon', 'wp-tabs-pro' ),
						'dependency'   => array( 'tabs_custom_icon', '==', '' ),
					),
					array(
						'type'       => 'content',
						'content'    => __( 'Or', 'wp-tabs-pro' ),
						'dependency' => array( 'tabs_custom_icon|tabs_content_icon', '==|==', '' ),
					),
					array(
						'id'           => 'tabs_custom_icon',
						'type'         => 'media',
						'library'      => 'image',
						'url'          => false,
						'class'        => 'tabs-custom-icon',
						'button_title' => __( 'Custom Icon', 'wp-tabs-pro' ),
						'remove_title' => __( 'Remove Icon', 'wp-tabs-pro' ),
						'dependency'   => array( 'tabs_content_icon', '==', '' ),
					),
					array(
						'id'         => 'tabs_linking',
						'type'       => 'checkbox',
						'wrap_class' => 'sp-tab__content_source',
						'title'      => __( 'Make it Deep-Linking', 'wp-tabs-pro' ),
						'title_help' => __( '<div class="wptabspro-info-label">Make it Deep-Linking</div><div class="wptabspro-short-content">Check to enable the ability to associate a direct link or URL with a specific tab</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-deep-linking-a-tab/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/deep-linking/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
						'default'    => false,
						'class'      => 'sp-tab__tab-linking',
					),
					array(
						'id'          => 'tabs_content_url',
						'type'        => 'text',
						'wrap_class'  => 'sp-tab__content_source',
						'placeholder' => 'https://www.example.com',
						'dependency'  => array( 'tabs_linking', '==', 'true' ),
					),
					array(
						'id'         => 'tabs_link_target',
						'type'       => 'select',
						'options'    => array(
							'_blank' => __( 'Open a New Tab', 'wp-tabs-pro' ),
							'_self'  => __( 'Same Tab', 'wp-tabs-pro' ),
						),
						'dependency' => array( 'tabs_linking', '==', 'true' ),
						'default'    => '_blank',
						'class'      => 'tabs-link-target',
					),
					array(
						'id'         => 'tabs_content_description',
						'type'       => 'wp_editor',
						'wrap_class' => 'sp-tab__content_source',
						'title'      => __( 'Description', 'wp-tabs-pro' ),
						'height'     => '150px',
						'sanitize'   => false,
					),
					array(
						'id'         => 'tabs_inactive',
						'type'       => 'checkbox',
						'wrap_class' => 'sp-tab__content_source',
						'title'      => __( 'Make it Inactive', 'wp-tabs-pro' ),
						'default'    => false,
					),
				),
				'dependency'             => array( 'sptpro_tab_type', '==', 'content-tabs' ),
			), // End of Content Tabs.
			// Post Tabs.
			array(
				'id'         => 'sptpro_post_type',
				'type'       => 'select',
				'title'      => __( 'Post Type', 'wp-tabs-pro' ),
				'options'    => 'post_type',
				'class'      => 'sp-tab__post_type',
				'attributes' => array(
					'placeholder' => __( 'Select Post Type', 'wp-tabs-pro' ),
					'style'       => 'min-width: 150px;',
				),
				'default'    => 'post',
				'dependency' => array( 'sptpro_tab_type', '==', 'post-tabs' ),
			),
			array(
				'id'         => 'sptpro_display_posts_from',
				'type'       => 'select',
				'title'      => __( 'Filter Posts', 'wp-tabs-pro' ),
				'options'    => array(
					'latest'        => __( 'Latest', 'wp-tabs-pro' ),
					'taxonomy'      => __( 'Taxonomy', 'wp-tabs-pro' ),
					'specific_post' => __( 'Specific Posts', 'wp-tabs-pro' ),
				),
				'default'    => 'latest',
				'class'      => 'chosen',
				'dependency' => array( 'sptpro_tab_type', '==', 'post-tabs' ),
			),
			array(
				'id'          => 'sptpro_specific_posts',
				'type'        => 'select',
				'title'       => __( 'Select Posts', 'wp-tabs-pro' ),
				'class'       => 'sp_tab_specific_posts',
				'options'     => 'all_posts',
				'chosen'      => true,
				'sortable'    => true,
				'multiple'    => true,
				'placeholder' => __( 'Choose Posts', 'wp-tabs-pro' ),
				'query_args'  => array(
					'posts_per_page' => -1,
				),
				'dependency'  => array(
					'sptpro_tab_type|sptpro_display_posts_from',
					'==|==',
					'post-tabs|specific_post',
				),
			),
			array(
				'id'         => 'sptpro_post_taxonomy',
				'type'       => 'select',
				'title'      => __( 'Select Taxonomy', 'wp-tabs-pro' ),
				'class'      => 'sp_tab_specific_posts',
				'options'    => 'taxonomies',
				'class'      => 'sp-tab__post_taxonomy',
				'attributes' => array(
					'placeholder' => __( 'Select Taxonomy', 'wp-tabs-pro' ),
					'style'       => 'min-width: 200px;',
				),
				'dependency' => array( 'sptpro_display_posts_from|sptpro_tab_type', '==|==', 'taxonomy|post-tabs' ),
			),
			array(
				'id'          => 'sptpro_taxonomy_terms',
				'type'        => 'select',
				'title'       => __( 'Choose Term(s)', 'wp-tabs-pro' ),
				'options'     => 'terms',
				'attributes'  => array(
					'style' => 'width: 280px;',
				),
				'class'       => 'sp-tab__taxonomy_terms',
				'help'        => __( 'Choose the taxonomy term(s) to show the posts from.', 'wp-tabs-pro' ),
				'dependency'  => array( 'sptpro_display_posts_from|sptpro_tab_type', '==|==', 'taxonomy|post-tabs' ),
				'multiple'    => true,
				'placeholder' => __( 'Select Term(s)', 'wp-tabs-pro' ),
				'chosen'      => true,
			),
			array(
				'id'         => 'taxonomy_operator',
				'type'       => 'select',
				'title'      => __( 'Operator', 'wp-tabs-pro' ),
				'class'      => 'sp-tab__taxonomy-operator',
				'options'    => array(
					'IN'     => __( 'IN', 'wp-tabs-pro' ),
					'AND'    => __( 'AND', 'wp-tabs-pro' ),
					'NOT IN' => __( 'NOT IN', 'wp-tabs-pro' ),
				),
				'default'    => 'IN',
				'help'       => '<b>IN</b> - Show posts which associate with one or more terms.<br/>
				<b>AND</b> - Show posts which match all terms.<br/>
				<b>NOT IN</b> - Show posts which don\'t match the terms.<br/>',
				'dependency' => array( 'sptpro_display_posts_from|sptpro_tab_type', '==|==', 'taxonomy|post-tabs' ),
			),
			array(
				'id'         => 'post_order_by',
				'type'       => 'select',
				'title'      => __( 'Order by', 'wp-tabs-pro' ),
				'options'    => array(
					'ID'         => __( 'ID', 'wp-tabs-pro' ),
					'date'       => __( 'Date', 'wp-tabs-pro' ),
					'rand'       => __( 'Random', 'wp-tabs-pro' ),
					'title'      => __( 'Title', 'wp-tabs-pro' ),
					'modified'   => __( 'Modified', 'wp-tabs-pro' ),
					'menu_order' => __( 'Menu Order', 'wp-tabs-pro' ),
					'post__in'   => __( 'Drag & Drop', 'wp-tabs-pro' ),
				),
				'default'    => 'date',
				'dependency' => array( 'sptpro_tab_type', '==', 'post-tabs' ),
			),
			array(
				'id'         => 'post_order',
				'type'       => 'select',
				'title'      => __( 'Order', 'wp-tabs-pro' ),
				'options'    => array(
					'ASC'  => __( 'Ascending', 'wp-tabs-pro' ),
					'DESC' => __( 'Descending', 'wp-tabs-pro' ),
				),
				'default'    => 'DESC',
				'dependency' => array( 'sptpro_tab_type', '==', 'post-tabs' ),
			),
			array(
				'id'         => 'number_of_total_posts',
				'type'       => 'spinner',
				'title'      => __( 'Limit', 'wp-tabs-pro' ),
				'class'      => 'number-of-total-posts',
				'help'       => __( 'Number of total posts to display. Default value is 6.', 'wp-tabs-pro' ),
				'default'    => '6',
				'min'        => 1,
				'max'        => 1000,
				'dependency' => array( 'sptpro_tab_type', '==', 'post-tabs' ),
			),
		), // End of fields array.
	)
);

//
// Metabox for the tabs.
// Set a unique slug-like ID.
//
$sptpro_shortcode_settings = 'sp_tab_shortcode_options';

//
// Create a metabox.
//
SP_WP_TABS::createMetabox(
	$sptpro_shortcode_settings,
	array(
		'title'     => __( 'Shortcode Section', 'wp-tabs-pro' ),
		'post_type' => 'sp_wp_tabs',
		'context'   => 'normal',
		'theme'     => 'light',
	)
);

//
// Create a section for tabs settings.
//
SP_WP_TABS::createSection(
	$sptpro_shortcode_settings,
	array(
		'title'  => __( 'Tabs Settings', 'wp-tabs-pro' ),
		'icon'   => 'fa fa-cog',
		'fields' => array(
			array(
				'id'         => 'sptpro_tabs_layout',
				'type'       => 'image_select',
				'class'      => 'sptpro_tabs_layout',
				'title'      => __( 'Tabs Layout', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Choose a tabs layout.', 'wp-tabs-pro' ),
				'title_help' => __( '<div class="wptabspro-info-label">Tabs Layout</div><div class="wptabspro-short-content">Choose a layout from five individual layout styles to customize how your tabs are displayed in the frontend.</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-choose-tabs-layout/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/tabs-layout/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
				'options'    => array(
					'horizontal'        => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-layout/horizontal-top.svg',
						'option_name' => __( 'Horizontal Top', 'wp-tabs-pro' ),
					),
					'horizontal-bottom' => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-layout/horizontal-bottom.svg',
						'option_name' => __( 'Horizontal Bottom', 'wp-tabs-pro' ),
					),
					'vertical'          => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-layout/vertical-left.svg',
						'option_name' => __( 'Vertical Left', 'wp-tabs-pro' ),
					),
					'vertical-right'    => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-layout/vertical-right.svg',
						'option_name' => __( 'Vertical Right', 'wp-tabs-pro' ),
					),
					'tabs-carousel'     => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-carousel-preset/Tabs-carousel.svg',
						'option_name' => __( 'Tabs Carousel', 'wp-tabs-pro' ),
					),
				),
				'radio'      => true,
				'default'    => 'horizontal',

			),

			array(
				'id'         => 'sptpro_tabs_horizontal_alignment',
				'type'       => 'image_select',
				'class'      => 'sptpro_tabs_horizontal_alignment',
				'title'      => __( 'Tabs Alignment', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Select an alignment for tabs.', 'wp-tabs-pro' ),
				'title_help' => __( '<div class="wptabspro-info-label">Tabs Alignment</div><div class="wptabspro-short-content">Choose where you want your tabs to appear – at the top, right, bottom, or left of your content, allowing you to customize their position to best suit your layout and design.</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-select-tabs-alignment/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/tabs-position-alignment/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
				'options'    => array(
					'tab-horizontal-alignment-left'      => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-alignment/horizontal-top/horizontal-left.svg',
						'option_name' => __( 'Left', 'wp-tabs-pro' ),
					),
					'tab-horizontal-alignment-center'    => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-alignment/horizontal-top/horizontal-center.svg',
						'option_name' => __( 'Center', 'wp-tabs-pro' ),
					),
					'tab-horizontal-alignment-right'     => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-alignment/horizontal-top/horizontal-right.svg',
						'option_name' => __( 'Right', 'wp-tabs-pro' ),
					),
					'tab-horizontal-alignment-justified' => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-alignment/horizontal-top/horizontal-justified.svg',
						'option_name' => __( 'Justified', 'wp-tabs-pro' ),
					),

				),
				'default'    => 'tab-horizontal-alignment-left',
				'dependency' => array( 'sptpro_tabs_layout', 'any', 'horizontal,horizontal-bottom', true ),
			),
			array(
				'id'         => 'sptpro_tabs_vertical_alignment',
				'type'       => 'image_select',
				'class'      => 'sptpro_tabs_vertical_alignment',
				'title'      => __( 'Tabs Alignment', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Select an alignment for tabs.', 'wp-tabs-pro' ),
				'title_help' => __( '<div class="wptabspro-info-label">Tabs Alignment</div><div class="wptabspro-short-content">Choose where you want your tabs to appear – at the top, right, bottom, or left of your content, allowing you to customize their position to best suit your layout and design.</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-select-tabs-alignment/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/tabs-position-alignment/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
				'options'    => array(
					'tab-vertical-alignment-top'       => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-alignment/vertical-left/vertical-top.svg',
						'option_name' => __( 'Top', 'wp-tabs-pro' ),
					),
					'tab-vertical-alignment-middle'    => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-alignment/vertical-left/vertical-center.svg',
						'option_name' => __( 'Center', 'wp-tabs-pro' ),
					),
					'tab-vertical-alignment-bottom'    => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-alignment/vertical-left/vertical-bottom.svg',
						'option_name' => __( 'Bottom', 'wp-tabs-pro' ),
					),
					'tab-vertical-alignment-justified' => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-alignment/vertical-left/vertical-justified.svg',
						'option_name' => __( 'Justified', 'wp-tabs-pro' ),
					),
				),
				'default'    => 'tab-vertical-alignment-top',
				'dependency' => array( 'sptpro_tabs_layout', 'any', 'vertical,vertical-right', true ),
			),
			array(
				'id'         => 'sptpro_tabs_carousel_alignment',
				'type'       => 'image_select',
				'class'      => 'sptpro_tabs_carousel',
				'title'      => __( 'Carousel Alignment', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Select an alignment for tabs carousel.', 'wp-tabs-pro' ),
				'title_help' => __( '<div class="wptabspro-info-label">Tabs Alignment</div><div class="wptabspro-short-content">Choose where you want your tabs carousel to appear – at the top, right, bottom, or left of your content, allowing you to customize their position to best suit your layout and design.</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-select-tabs-alignment/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/tabs-position-alignment/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
				'options'    => array(
					'carousel-horizontal-top'    => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-carousel-preset/horizontal-top.svg',
						'option_name' => __( 'Top', 'wp-tabs-pro' ),
					),
					'carousel-horizontal-bottom' => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-carousel-preset/horizontal-bottom.svg',
						'option_name' => __( 'Bottom', 'wp-tabs-pro' ),
					),
					'carousel-vertical-left'     => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-carousel-preset/vertical-left.svg',
						'option_name' => __( 'Left', 'wp-tabs-pro' ),
					),
					'carousel-vertical-right'    => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/tabs-carousel-preset/vertical-right.svg',
						'option_name' => __( 'Right', 'wp-tabs-pro' ),
					),

				),
				'default'    => 'carousel-horizontal-top',
				'dependency' => array( 'sptpro_tabs_layout', '==', 'tabs-carousel', true ),
			),
			array(
				'id'         => 'sptpro_slides_to_show',
				'class'      => 'sptpro_number_of_columns',
				'type'       => 'column',
				'title'      => __( 'Tabs Columns', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Number of the tab items to display in different devices.', 'wp-tabs-pro' ),
				'help'       => '<i class="fa fa-television"></i> LARGE DESKTOP - Screens larger than 1280px.<br/>
					<i class="fa fa-desktop"></i> DESKTOP - Screens smaller than 1280px.<br/>
					<i class="fa fa-laptop"></i> LAPTOP - Screens smaller than 980px.<br/>
					<i class="fa fa-tablet"></i> TABLET - Screens smaller than 736px.<br/>
					<i class="fa fa-mobile"></i> MOBILE - Screens smaller than 480px.<br/>',
				'default'    => array(
					'lg_desktop' => '5',
					'desktop'    => '4',
					'laptop'     => '3',
					'tablet'     => '2',
					'mobile'     => '1',
				),
				'min'        => '1',
				'dependency' => array( 'sptpro_tabs_layout', '==', 'tabs-carousel', true ),
			),
			array(
				'id'         => 'sptpro_tabs_variable_width',
				'type'       => 'switcher',
				'title'      => __( 'Variable Width', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Enable/Disable scrollable tabs variable width.', 'wp-tabs-pro' ),
				'title_help' => __( '<div class="wptabspro-info-label">Variable Width</div><div class="wptabspro-short-content">Enable the Variable Width to allow each individual tab in your carousel to have its own unique width. This flexibility lets you create fascinating and responsive designs, accommodating content of different sizes and aspect ratios.</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-enable-variable-width-for-scrollable-tabs/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/tabs-layout/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
				'text_on'    => __( 'Enabled', 'wp-tabs-pro' ),
				'text_off'   => __( 'Disabled', 'wp-tabs-pro' ),
				'text_width' => 96,
				'default'    => false,
				'dependency' => array( 'sptpro_tabs_layout', '==', 'tabs-carousel', true ),
			),
			array(
				'id'         => 'sptpro_tabs_loop',
				'type'       => 'switcher',
				'title'      => __( 'Enable Tabs Loop', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Enable/Disable scrollable tabs loop.', 'wp-tabs-pro' ),
				'text_on'    => __( 'Enabled', 'wp-tabs-pro' ),
				'text_off'   => __( 'Disabled', 'wp-tabs-pro' ),
				'text_width' => 96,
				'default'    => true,
				'dependency' => array( 'sptpro_tabs_layout', '==', 'tabs-carousel', true ),
			),

			array(
				'id'         => 'sptpro_tabs_carousel_navigation',
				'type'       => 'fieldset',
				'class'      => 'sptpro_tabs_carousel_navigation_style',
				'title'      => 'Group',
				'title'      => __( 'Navigation', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Set navigation style.', 'wp-tabs-pro' ),
				'fields'     => array(
					array(
						'id'       => 'tabs_navigation_styles',
						'type'     => 'button_set',
						'class'    => 'tabs_navigation_styles',
						'top_text' => 'Style',
						'options'  => array(
							'angle'          => '<i class="fa fa-angle-right"></i>',
							'chevron'        => '<i class="fa fa-chevron-right"></i>',
							'arrow-left'     => '<i class="fa fa-arrow-right"></i>',
							'chevron-circle' => '<i class="fa fa-chevron-circle-right"></i>',
						),
						'default'  => 'chevron',
					),
					array(
						'id'         => 'tabs_navigation_icons_size',
						'type'       => 'spacing',
						'style'      => false,
						'color'      => false,
						'all'        => true,
						'top_text'   => __( 'Size', 'wp-tabs-pro' ),
						'units'      => array( 'px' ),
						'default'    => array(
							'all' => '20',
						),
						'attributes' => array(
							'min' => 0,
						),
					),
					array(
						'id'      => 'sptpro_scroll_tab_icon_color',
						'type'    => 'color_group',
						'options' => array(
							'arrow_color' => __( 'Color', 'wp-tabs-pro' ),
							'hover_color' => __( 'Hover Color', 'wp-tabs-pro' ),
						),
						'default' => array(
							'arrow_color' => '#444',
							'hover_color' => '#444',
						),
					),
				),
				'dependency' => array( 'sptpro_tabs_layout', '==', 'tabs-carousel', true ),
			),

			array(
				'id'         => 'sptpro_tabs_activator_event',
				'type'       => 'radio',
				'title'      => __( 'Activator Event', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Select an activator event for tabs.', 'wp-tabs-pro' ),
				'title_help' => __( '<div class="wptabspro-info-label">Activator Event</div><div class="wptabspro-short-content">Set an event to switch between tabs with Autoplay, On Click, or Mouse Hover.</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-set-tabs-activator-events/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/activator-events/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
				'options'    => array(
					'tabs-activator-event-click' => __( 'On Click', 'wp-tabs-pro' ),
					'tabs-activator-event-hover' => __( 'Mouseover', 'wp-tabs-pro' ),
					'tabs-activator-event-auto'  => __( 'AutoPlay', 'wp-tabs-pro' ),
				),
				'default'    => 'tabs-activator-event-click',
				'dependency' => array( 'sptpro_tabs_layout', '!=', 'tabs-carousel', true ),
			),
			array(
				'id'         => 'sptpro_autoplay_time',
				'type'       => 'spinner',
				'title'      => __( 'AutoPlay Delay Time', 'wp-tabs-pro' ),
				'title_info' => __( '<div class="wptabspro-info-label">AutoPlay Delay Time</div>Set autoplay delay or interval time. The amount of time to delay between automatically cycling a weather item. e.g. 1000 milliseconds(ms) = 1 second. ', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Set autoplay time in milisecond.', 'wp-tabs-pro' ),
				'unit'       => 'ms',
				'min'        => 1000,
				'max'        => 100000,
				'default'    => 3000,
				'dependency' => array( 'sptpro_tabs_activator_event', '==', 'tabs-activator-event-auto' ),
			),
			array(
				'id'         => 'sptpro_pause_on_hover',
				'type'       => 'switcher',
				'title'      => __( 'Pause on Hover', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Enable/Disable tabs stop on hover.', 'wp-tabs-pro' ),
				'text_on'    => __( 'Enabled', 'wp-tabs-pro' ),
				'text_off'   => __( 'Disabled', 'wp-tabs-pro' ),
				'text_width' => 96,
				'default'    => true,
				'dependency' => array( 'sptpro_tabs_activator_event', '==', 'tabs-activator-event-auto' ),
			),
			array(
				'id'         => 'sptpro_tab_opened',
				'type'       => 'spinner',
				'title'      => __( 'Initial Open Tab', 'wp-tabs-pro' ),
				'subtitle'   => __( 'The tab which will remain initially opened on page load.', 'wp-tabs-pro' ),
				'title_help' => '<div class="wptabspro-img-tag"><img src="' . plugin_dir_url( __DIR__ ) . 'partials/models/assets/images/help-visuals/initial-tab-opened.svg" alt="Initial Open Tab"></div><div class="wptabspro-info-label">' . __( 'Initial Open Tab', 'wp-tabs-pro' ) . '</div>',
				'min'        => 1,
				'default'    => 1,
			),
			array(
				'id'         => 'sptpro_preloader',
				'type'       => 'switcher',
				'title'      => __( 'Preloader', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Tabs will be hidden until page load completed.', 'wp-tabs-pro' ),
				'text_on'    => __( 'Enabled', 'wp-tabs-pro' ),
				'text_off'   => __( 'Disabled', 'wp-tabs-pro' ),
				'text_width' => 96,
				'default'    => true,
			),
		), // Fields array end.
	)
); // End of tabs settings.

//
// Carousel settings section begin.
//
SP_WP_TABS::createSection(
	$sptpro_shortcode_settings,
	array(
		'title'  => __( 'Display Options', 'wp-tabs-pro' ),
		'icon'   => 'fa fa-th-large',
		'fields' => array(
			array(
				'id'         => 'sptpro_section_title',
				'type'       => 'switcher',
				'title'      => __( 'Tab Group Section Title', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Show/hide tabs set section title.', 'wp-tabs-pro' ),
				'default'    => true,
				'text_on'    => __( 'Show', 'wp-tabs-pro' ),
				'text_off'   => __( 'Hide', 'wp-tabs-pro' ),
				'text_width' => 75,
			),
			array(
				'id'              => 'sptpro_margin_between_tabs',
				'type'            => 'spacing',
				'title'           => __( 'Margin Between Tabs', 'wp-tabs-pro' ),
				'subtitle'        => __( 'Set a space between tabs.', 'wp-tabs-pro' ),
				'title_help'      => '<div class="wptabspro-img-tag"><img src="' . plugin_dir_url( __DIR__ ) . 'partials/models/assets/images/help-visuals/margin-between-tabs.svg" alt="Margin Between Tabs"></div><div class="wptabspro-info-label">' . __( 'Margin between Tabs', 'wp-tabs-pro' ) . '</div>',
				'all'             => true,
				'all_icon'        => '<i class="fa fa-arrows-h"></i>',
				'all_placeholder' => 'margin',
				'default'         => array(
					'all' => '10',
				),
				'units'           => array(
					'px',
				),
			),
			array(
				'id'         => 'sptpro_hush_url',
				'type'       => 'switcher',
				'title'      => __( 'Hash Anchor', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Show/hide tabs hash url.', 'wp-tabs-pro' ),
				'default'    => true,
				'text_on'    => __( 'Show', 'wp-tabs-pro' ),
				'text_off'   => __( 'Hide', 'wp-tabs-pro' ),
				'text_width' => 75,
			),
			array(
				'type'       => 'subheading',
				'content'    => __( 'Tabs Icon', 'wp-tabs-pro' ),
				'dependency' => array( 'sptpro_tab_type', '==', 'content-tabs' ),
			),

			array(
				'id'         => 'sptpro_tabs_icon',
				'type'       => 'switcher',
				'title'      => __( 'Tabs Icon', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Show/hide the tabs icon.', 'wp-tabs-pro' ),
				'default'    => true,
				'text_on'    => __( 'Show', 'wp-tabs-pro' ),
				'text_off'   => __( 'Hide', 'wp-tabs-pro' ),
				'text_width' => 75,
				'dependency' => array( 'sptpro_tab_type', '==', 'content-tabs' ),
			),
			array(
				'id'              => 'sptpro_tab_icon_size',
				'type'            => 'spacing',
				'title'           => __( 'Icon Size', 'wp-tabs-pro' ),
				'subtitle'        => __( 'Set tabs icon size.', 'wp-tabs-pro' ),
				'all'             => true,
				'all_text'        => false,
				'all_placeholder' => 'size',
				'default'         => array(
					'all' => '16',
				),
				'units'           => array(
					'px',
				),
				'dependency'      => array(
					'sptpro_tabs_icon|sptpro_tab_type',
					'==|==',
					'true|content-tabs',
				),
			),
			array(
				'id'              => 'sptpro_icon_space_title',
				'type'            => 'spacing',
				'title'           => __( 'Space Between Title and Icon', 'wp-tabs-pro' ),
				'subtitle'        => __( 'Set a space between title and icon.', 'wp-tabs-pro' ),
				'title_help'      => '<div class="wptabspro-img-tag"><img src="' . plugin_dir_url( __DIR__ ) . 'partials/models/assets/images/help-visuals/space-between-title-and-icon.svg" alt="Space Between Title and Icon"></div><div class="wptabspro-info-label">' . __( 'Space Between Title and Icon', 'wp-tabs-pro' ) . '</div>',
				'all_icon'        => '<i class="fa fa-arrows-h"></i>',
				'all'             => true,
				'all_text'        => false,
				'all_placeholder' => 'size',
				'default'         => array(
					'all' => '10',
				),
				'units'           => array(
					'px',
				),
				'dependency'      => array(
					'sptpro_tabs_icon|sptpro_tab_type',
					'==|==',
					'true|content-tabs',
				),
			),
			array(
				'id'         => 'sptpro_tab_icon_color',
				'type'       => 'color_group',
				'title'      => __( 'Icon Color', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Set tab icon color.', 'wp-tabs-pro' ),
				'options'    => array(
					'tab-icon-color'        => __( 'Color', 'wp-tabs-pro' ),
					'tab-icon-color-active' => __( 'Active Color', 'wp-tabs-pro' ),
					'tab-icon-color-hover'  => __( 'Hover Color', 'wp-tabs-pro' ),
				),
				'default'    => array(
					'tab-icon-color'        => '#444',
					'tab-icon-color-active' => '#444',
					'tab-icon-color-hover'  => '#444',
				),
				'dependency' => array(
					'sptpro_tabs_icon|sptpro_tab_type',
					'==|==',
					'true|content-tabs',
				),
			),
			array(
				'id'         => 'sptpro_tab_icon_position',
				'type'       => 'image_select',
				'class'      => 'sptpro_tab_icon_position_left',
				'title'      => __( 'Icon Position', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Select tab icon position.', 'wp-tabs-pro' ),
				'title_help' => __( '<div class="wptabspro-info-label">Icon Position</div><div class="wptabspro-short-content">This option allows you to specify the position of icons within your tab interface. You can place icons to the Top, Right, Bottom and Left of tab\'s title.</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-select-tabs-icon-position/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/tabs-icon-position/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
				'options'    => array(
					'tab-icon-position-left'  => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/icon-position/horizontal-icon-position-left.svg',
						'option_name' => __( 'Left', 'wp-tabs-pro' ),
					),
					'tab-icon-position-top'   => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/icon-position/horizontal-icon-position-top.svg',
						'option_name' => __( 'Top', 'wp-tabs-pro' ),
					),
					'tab-icon-position-right' => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/icon-position/horizontal-icon-position-right.svg',
						'option_name' => __( 'Right', 'wp-tabs-pro' ),
					),
				),
				'radio'      => true,
				'default'    => 'tab-icon-position-left',
				'dependency' => array(
					'sptpro_tabs_icon|sptpro_tabs_layout|sptpro_tab_type',
					'==|any|==',
					'true|horizontal,horizontal-bottom,tabs-carousel|content-tabs',
				),
			),
			array(
				'id'         => 'sptpro_tab_icon_position_vertical',
				'type'       => 'image_select',
				'class'      => 'sptpro_tab_icon_position_vertical',
				'title'      => __( 'Icon Position', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Select tab icon position.', 'wp-tabs-pro' ),
				'title_help' => __( '<div class="wptabspro-info-label">Icon Position</div><div class="wptabspro-short-content">This option allows you to specify the position of icons within your tab interface. You can place icons to the Top, Right, Bottom and Left of tab\'s title.</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-select-tabs-icon-position/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/tabs-icon-position/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
				'options'    => array(
					'vertical-tab-icon-position-left'  => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/icon-position/vertical-icon-position-left.svg',
						'option_name' => __( 'Left', 'wp-tabs-pro' ),
					),
					'vertical-tab-icon-position-top'   => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/icon-position/vertical-icon-position-top.svg',
						'option_name' => __( 'Top', 'wp-tabs-pro' ),
					),
					'vertical-tab-icon-position-right' => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/icon-position/vertical-icon-position-right.svg',
						'option_name' => __( 'Right', 'wp-tabs-pro' ),
					),
				),
				'radio'      => true,
				'default'    => 'vertical-tab-icon-position-left',
				'dependency' => array(
					'sptpro_tabs_icon|sptpro_tabs_layout|sptpro_tab_type',
					'==|any|==',
					'true|vertical,vertical-right,tabs-carousel|content-tabs',
				),
			),

			array(
				'type'    => 'subheading',
				'content' => __( 'Tabs Title and Description', 'wp-tabs-pro' ),
			),

			array(
				'id'         => 'sptpro_item_title',
				'type'       => 'switcher',
				'title'      => __( 'Tabs Title', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Show/hide tabs title.', 'wp-tabs-pro' ),
				'default'    => true,
				'text_on'    => __( 'Show', 'wp-tabs-pro' ),
				'text_off'   => __( 'Hide', 'wp-tabs-pro' ),
				'text_width' => 75,
			),

			array(
				'id'         => 'sptpro_showhide_subtitle',
				'type'       => 'switcher',
				'title'      => __( 'Tabs Subtitle', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Show/hide tabs subtitle.', 'wp-tabs-pro' ),
				'default'    => true,
				'text_on'    => __( 'Show', 'wp-tabs-pro' ),
				'text_off'   => __( 'Hide', 'wp-tabs-pro' ),
				'text_width' => 75,
			),

			array(
				'id'         => 'sptpro_title_heading_tag',
				'type'       => 'select',
				'title'      => __( 'Title HTML Tag', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Select a tag for tabs title.', 'wp-tabs-pro' ),
				'options'    => array(
					'H1'   => 'H1',
					'H2'   => 'H2',
					'H3'   => 'H3',
					'H4'   => 'H4',
					'H5'   => 'H5',
					'H6'   => 'H6',
					'div'  => 'Div',
					'span' => 'Span',
				),
				'default'    => 'H4',
				'radio'      => true,
				'dependency' => array(
					'sptpro_item_title',
					'==',
					'true',
				),
			),
			array(
				'id'         => 'sptpro_active_indicator_arrow',
				'type'       => 'switcher',
				'title'      => __( 'Active Tab Indicator Arrow', 'wp-tabs-pro' ),
				'subtitle'   => __( 'To show this indicator, you should set margin between tabs and description', 'wp-tabs-pro' ),
				'title_help' => '<div class="wptabspro-img-tag"><img src="' . plugin_dir_url( __DIR__ ) . 'partials/models/assets/images/help-visuals/active-tab-indicator-arrow.svg" alt="Active Tab Indicator"></div><div class="wptabspro-info-label">' . __( 'Active Tab Indicator Arrow', 'wp-tabs-pro' ) . '</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-configure-active-tab-indicator-arrow/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/active-tab-indicator-arrow/" target="_blank">' . __( 'Live Demo', 'wp-tabs-pro' ) . '</a>',
				'default'    => false,
				'text_on'    => __( 'Show', 'wp-tabs-pro' ),
				'text_off'   => __( 'Hide', 'wp-tabs-pro' ),
				'text_width' => 75,
				'dependency' => array(
					'sptpro_tabs_layout',
					'!=',
					'tabs-carousel',
				),
			),
			array(
				'id'         => 'sptpro_tabs_bg_color_type',
				'type'       => 'button_set',
				'title'      => __( 'Title Background Color Type ', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Choose a color type for the title background.', 'wp-tabs-pro' ),
				'title_help' => '<div class="wptabspro-img-tag"><img src="' . plugin_dir_url( __DIR__ ) . 'partials/models/assets/images/help-visuals/title-background-color-type.svg" alt="Title Background Color Type"></div><div class="wptabspro-info-label">' . __( 'Title Background Color Type', 'wp-tabs-pro' ) . '</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-set-tabs-title-background-color/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/title-background-color/" target="_blank">Live Demo</a>',
				'options'    => array(
					'solid'    => __( 'Solid', 'wp-tabs-pro' ),
					'gradient' => __( 'Gradient', 'wp-tabs-pro' ),
				),
				'default'    => 'solid',
				'dependency' => array(
					'sptpro_item_title',
					'==',
					'true',
				),
			),
			array(
				'id'         => 'sptpro_title_bg_color',
				'type'       => 'color_group',
				'title'      => __( 'Title Background Color', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Set tabs title background color.', 'wp-tabs-pro' ),
				'options'    => array(
					'title-bg-color'        => __( 'Background', 'wp-tabs-pro' ),
					'title-active-bg-color' => __( 'Active Background', 'wp-tabs-pro' ),
					'title-hover-bg-color'  => __( 'Hover Background', 'wp-tabs-pro' ),
				),
				'default'    => array(
					'title-bg-color'        => '#eee',
					'title-active-bg-color' => '#fff',
					'title-hover-bg-color'  => '#fff',
				),
				'dependency' => array(
					'sptpro_item_title|sptpro_tabs_bg_color_type',
					'==|==',
					'true|solid',
				),
			),
			array(
				'id'                    => 'sptpro_tabs_bg_gradient_color',
				'type'                  => 'background',
				'title'                 => __( 'Gradient Color', 'wp-tabs-pro' ),
				'subtitle'              => __( 'Set gradient color for the tab title background.', 'wp-tabs-pro' ),
				'background_gradient'   => true,
				'background_color'      => true,
				'background_image'      => false,
				'background_position'   => false,
				'background_repeat'     => false,
				'background_attachment' => false,
				'background_size'       => false,
				'default'               => array(
					'background-color'              => '#fff',
					'background-gradient-color'     => '#eee',
					'background-gradient-direction' => '135deg',
				),
				'dependency'            => array(
					'sptpro_item_title|sptpro_tabs_bg_color_type',
					'==|==',
					'true|gradient',
				),
			),
			array(
				'id'         => 'sptpro_title_padding',
				'type'       => 'spacing',
				'title'      => __( 'Title Padding', 'wp-tabs-pro' ),
				'top_text'   => __( 'Top', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Set tabs title padding.', 'wp-tabs-pro' ),
				'title_help' => '<div class="wptabspro-img-tag"><img src="' . plugin_dir_url( __DIR__ ) . 'partials/models/assets/images/help-visuals/title-padding.svg" alt="Title Padding"></div><div class="wptabspro-info-label">' . __( 'Title Padding', 'wp-tabs-pro' ) . '</div>',
				'units'      => array( 'px' ),
				'default'    => array(
					'left'   => '15',
					'top'    => '15',
					'bottom' => '15',
					'right'  => '15',
				),
				'dependency' => array(
					'sptpro_item_title',
					'==',
					'true',
				),
			),
			array(
				'id'            => 'sptpro_tabs_border',
				'type'          => 'border',
				'title'         => __( 'Border', 'wp-tabs-pro' ),
				'subtitle'      => __( 'Set tabs border.', 'wp-tabs-pro' ),
				'all_icon'      => false,
				'all'           => true,
				'border_radius' => true,
				'default'       => array(
					'all'           => 1,
					'style'         => 'solid',
					'color'         => '#cccccc',
					'border_radius' => '2',

				),
				'units'         => array(
					'px',
					'%',
				),
			),
			array(
				'id'         => 'sptpro_active_tab_style_horizontal',
				'type'       => 'image_select',
				'class'      => 'sp_active_tab_style_horizontal',
				'title'      => __( 'Active Tab Style', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Choose active tab style.', 'wp-tabs-pro' ),
				'title_help' => __( '<div class="wptabspro-info-label">Active Tab Style</div><div class="wptabspro-short-content">Choose how the currently selected tab looks. You can add a line to the Top or Bottom of tab\'s title to make it stand out.</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-set-active-tab-style/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/active-tab-style/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
				'options'    => array(
					'horizontal-active-tab-normal'      => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/active-tab-style/horizontal-active-tab-normal.svg',
						'option_name' => __( 'Normal', 'wp-tabs-pro' ),
					),
					'horizontal-active-tab-top-line'    => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/active-tab-style/horizontal-active-tab-top-line.svg',
						'option_name' => __( 'Top', 'wp-tabs-pro' ),
					),
					'horizontal-active-tab-bottom-line' => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/active-tab-style/horizontal-active-tab-bottom-line.svg',
						'option_name' => __( 'Bottom', 'wp-tabs-pro' ),
					),
				),
				'radio'      => true,
				'default'    => 'horizontal-active-tab-normal',
				'dependency' => array( 'sptpro_tabs_layout', 'any', 'horizontal,horizontal-bottom,tabs-carousel' ),
			),
			array(
				'id'         => 'sptpro_active_tab_style_vertical',
				'type'       => 'image_select',
				'class'      => 'sp_active_tab_style_vertical',
				'title'      => __( 'Active Tab Style', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Choose active tab style.', 'wp-tabs-pro' ),
				'title_help' => __( '<div class="wptabspro-info-label">Active Tab Style</div><div class="wptabspro-short-content">Choose how the currently selected tab looks. You can add a line to the Top or Bottom of tab\'s title to make it stand out.</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-set-active-tab-style/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/active-tab-style/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
				'options'    => array(
					'vertical-active-tab-normal'     => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/active-tab-style/vertical-active-tab-normal.svg',
						'option_name' => __( 'Normal', 'wp-tabs-pro' ),
					),
					'vertical-active-tab-left-line'  => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/active-tab-style/vertical-active-tab-left-line.svg',
						'option_name' => __( 'Left', 'wp-tabs-pro' ),
					),
					'vertical-active-tab-right-line' => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/active-tab-style/vertical-active-tab-right-line.svg',
						'option_name' => __( 'Right', 'wp-tabs-pro' ),
					),
				),
				'radio'      => true,
				'default'    => 'vertical-active-tab-normal',
				'dependency' => array( 'sptpro_tabs_layout', 'any', 'vertical,vertical-right,tabs-carousel' ),
			),

			array(
				'id'         => 'sptpro_active_top_border_elements',
				'type'       => 'border',
				'class'      => 'sptpro_active_top_border_elements_horizontal',
				'title'      => __( 'Active Tab Top Line Border', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Set a top line border width and color.', 'wp-tabs-pro' ),
				'all_icon'   => false,
				'all'        => true,
				'style'      => false,
				'default'    => array(
					'all'   => 3,
					'color' => '#00a455',
				),
				'dependency' => array( 'sptpro_tabs_layout|sptpro_active_tab_style_horizontal', 'any|!=', 'horizontal,horizontal-bottom,tabs-carousel|horizontal-active-tab-normal', true ),
			),

			array(
				'id'         => 'sptpro_active_left_border_elements',
				'type'       => 'border',
				'class'      => 'sptpro_active_left_border_elements_vertical',
				'title'      => __( 'Active Tab Left Line Border', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Set a top line border width and color.', 'wp-tabs-pro' ),
				'all_icon'   => false,
				'all'        => true,
				'style'      => false,
				'default'    => array(
					'all'   => 3,
					'color' => '#00a455',
				),
				'dependency' => array( 'sptpro_tabs_layout|sptpro_active_tab_style_vertical', 'any|!=', 'vertical,vertical-right,tabs-carousel|vertical-active-tab-normal', true ),
			),

			array(
				'id'              => 'sptpro_margin_between_tabs_and_desc',
				'type'            => 'spacing',
				'class'           => 'margin_between_tabs_and_desc',
				'bottom_icon'     => '<i class="fa fa-arrows-v"></i>',
				'title'           => __( 'Margin Between Tabs and Description', 'wp-tabs-pro' ),
				'subtitle'        => __( 'Set a space between tabs and description.', 'wp-tabs-pro' ),
				'title_help'      => '<div class="wptabspro-img-tag"><img src="' . plugin_dir_url( __DIR__ ) . 'partials/models/assets/images/help-visuals/margin-between-tabs-and-description.svg" alt="Margin Between Tabs and Description"></div><div class="wptabspro-info-label">' . __( 'Margin Between Tabs and Description', 'wp-tabs-pro' ) . '</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-set-margin-between-tabs-and-description/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/margin-between-tabs-and-description/" target="_blank">Live Demo</a>',
				'all_placeholder' => 'margin',
				'top'             => false,
				'left'            => false,
				'bottom'          => true,
				'right'           => false,
				'default'         => array(
					'bottom' => '0',
				),
				'units'           => array(
					'px',
				),
			),
			array(
				'id'       => 'sptpro_desc_bg_color',
				'type'     => 'color',
				'title'    => __( 'Description Background Color', 'wp-tabs-pro' ),
				'subtitle' => __( 'Set description background color.', 'wp-tabs-pro' ),
				'default'  => '#ffffff',
			),
			array(
				'id'         => 'sptpro_desc_padding',
				'type'       => 'spacing',
				'title'      => __( 'Description Padding', 'wp-tabs-pro' ),
				'top_text'   => __( 'Top', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Set description padding.', 'wp-tabs-pro' ),
				'title_help' => '<div class="wptabspro-img-tag"><img src="' . plugin_dir_url( __DIR__ ) . 'partials/models/assets/images/help-visuals/description-padding.svg" alt="Description Padding"></div><div class="wptabspro-info-label"> ' . __( 'Description Padding', 'wp-tabs-pro' ) . '</div>',
				'units'      => array( 'px' ),
				'default'    => array(
					'left'   => '20',
					'top'    => '20',
					'bottom' => '20',
					'right'  => '20',
				),
			),
			array(
				'id'            => 'sptpro_desc_border',
				'type'          => 'border',
				'title'         => __( 'Description Border', 'wp-tabs-pro' ),
				'subtitle'      => __( 'Set description border.', 'wp-tabs-pro' ),
				'all_icon'      => false,
				'all'           => true,
				'style'         => false,
				'border_radius' => true,
				'default'       => array(
					'all'           => 1,
					'style'         => 'solid',
					'color'         => '#cccccc',
					'border_radius' => '0',
				),
			),
			array(
				'id'         => 'sptpro_flat_tab_style_horizontal',
				'type'       => 'image_select',
				'class'      => 'sp_flat_tab_style_horizontal',
				'title'      => __( 'Flat Tab Style', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Choose flat tab style.', 'wp-tabs-pro' ),
				'title_help' => __( '<div class="wptabspro-info-label">Flat Tab Style</div><div class="wptabspro-short-content">Select the Underline option to enhance your tabs with flat underline positioned below the tab navigation for a clean and modern look.</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-make-tab-flat-style/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/flat-contained-tabs/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
				'options'    => array(
					'horizontal-flat-tab-normal'    => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/flat-tab-style/horizontal-normal.svg',
						'option_name' => __( 'Normal', 'wp-tabs-pro' ),
					),
					'horizontal-flat-tab-underline' => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/flat-tab-style/horizontal-underline.svg',
						'option_name' => __( 'Underline', 'wp-tabs-pro' ),
					),
				),
				'radio'      => true,
				'default'    => 'horizontal-flat-tab-normal',
				'dependency' => array( 'sptpro_tabs_layout', 'any', 'horizontal,horizontal-bottom,tabs-carousel' ),
			),

			array(
				'id'         => 'sptpro_flat_tab_style_vertical',
				'type'       => 'image_select',
				'class'      => 'sp_flat_tab_style_vertical',
				'title'      => __( 'Flat Tab Style', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Choose flat tab style.', 'wp-tabs-pro' ),
				'title_help' => __( '<div class="wptabspro-info-label">Flat Tab Style</div><div class="wptabspro-short-content">Select the Underline option to enhance your tabs with flat underline positioned below the tab navigation for a clean and modern look.</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-make-tab-flat-style/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/flat-contained-tabs/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
				'options'    => array(
					'vertical-flat-tab-normal'    => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/flat-tab-style/vertical-normal.svg',
						'option_name' => __( 'Normal', 'wp-tabs-pro' ),
					),
					'vertical-flat-tab-underline' => array(
						'image'       => WP_TABS_PRO_URL . '/admin/img/flat-tab-style/vertical-underline.svg',
						'option_name' => __( 'Underline', 'wp-tabs-pro' ),
					),
				),
				'radio'      => true,
				'default'    => 'vertical-flat-tab-normal',
				'dependency' => array( 'sptpro_tabs_layout', 'any', 'vertical,vertical-right,tabs-carousel' ),
			),

			array(
				'id'         => 'sptpro_tab_flat_style_border',
				'type'       => 'border',
				'class'      => 'sptpro_tab_flat_border_style',
				'title'      => __( 'Underline Style', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Set tabs\' underline width and color.', 'wp-tabs-pro' ),
				'all_icon'   => false,
				'all'        => true,
				'style'      => false,
				'default'    => array(
					'all'   => 6,
					'style' => 'solid',
					'color' => '#111',
				),
				'dependency' => array( 'sptpro_flat_tab_style_horizontal', '!=', 'horizontal-flat-tab-normal' ),
			),
			array(
				'id'         => 'sptpro_strip_html_tags',
				'type'       => 'checkbox',
				'title'      => __( 'Strip all HTML Tags', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Check to strip all HTML tags of description content.', 'wp-tabs-pro' ),
				'title_help' => __( '<div class="wptabspro-info-label">Strip all HTML Tags</div><div class="wptabspro-short-content">Check to strip all formatting and special tags from the tab descriptions to keep the content clean and simple.</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-strip-all-html-tags-of-description-content/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/strip-all-html-tags/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
				'default'    => false,
			),
			array(
				'id'         => 'sptpro_fixed_height',
				'type'       => 'button_set',
				'title'      => __( 'Content Height', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Select content height.', 'wp-tabs-pro' ),
				'title_help' => '<div class="wptabspro-img-tag"><img src="' . plugin_dir_url( __DIR__ ) . 'partials/models/assets/images/help-visuals/content-height.svg" alt="Content Height"></div><div class="wptabspro-info-label"> ' . __( 'Content Height', 'wp-tabs-pro' ) . '</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-set-tabs-content-height/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/tabs-fixed-content-height/" target="_blank">Live Demo</a>',
				'options'    => array(
					'auto'   => __( 'Auto', 'wp-tabs-pro' ),
					'custom' => __( 'Custom', 'wp-tabs-pro' ),
				),
				'default'    => 'auto',
			),
			array(
				'id'              => 'sptpro_fixed_height_number',
				'type'            => 'spacing',
				'title'           => __( 'Content Custom Height', 'wp-tabs-pro' ),
				'subtitle'        => __( 'Set custom height for the tabs content.', 'wp-tabs-pro' ),
				'all'             => true,
				'all_icon'        => '<i class="fa fa-arrows-v"></i>',
				'all_placeholder' => 'margin',
				'default'         => array(
					'all' => '300',
				),
				'units'           => array(
					'px',
				),
				'dependency'      => array( 'sptpro_fixed_height', '==', 'custom' ),
			),
			array(
				'type'    => 'subheading',
				'content' => __( 'Small Screen', 'wp-tabs-pro' ),
			),
			array(
				'id'              => 'sptpro_set_small_screen',
				'type'            => 'spacing',
				'title'           => __( 'When Screen Width is Less Than:', 'wp-tabs-pro' ),
				'all'             => true,
				'all_text'        => false,
				'all_placeholder' => 'margin',
				'default'         => array(
					'all' => '480',
				),
				'units'           => array(
					'px',
				),
			),
			array(
				'id'         => 'sptpro_tabs_on_small_screen',
				'type'       => 'radio',
				'title'      => __( 'Tabs Mode on Small Screen', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Choose a tabs mode on small screen.', 'wp-tabs-pro' ),
				'title_help' => __( '<div class="wptabspro-info-label">Tabs Mode on Small Screen</div><div class="wptabspro-short-content">Choose how your tabs behave on small screens, such as mobile devices. You can select "Full Width" to maintain the current layout or "Accordion" to switch to a collapsible format, ensuring the best user experience on mobile.</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-configure-tabs-mood-on-small-screen/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/tabs-mood-on-small-screen/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
				'options'    => array(
					'full_widht'     => __( 'Full Width', 'wp-tabs-pro' ),
					'accordion_mode' => __( 'Accordion', 'wp-tabs-pro' ),
				),
				'default'    => 'full_widht',
			),
			array(
				'id'         => 'sptpro_expand_and_collapse_icon',
				'type'       => 'switcher',
				'title'      => __( 'Expand and Collapse Icon', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Show/Hide expand and collapse icon.', 'wp-tabs-pro' ),
				'default'    => true,
				'text_on'    => __( 'Show', 'wp-tabs-pro' ),
				'text_off'   => __( 'Hide', 'wp-tabs-pro' ),
				'text_width' => 75,
				'dependency' => array( 'sptpro_tabs_on_small_screen', '==', 'accordion_mode' ),
			),

			array(
				'type'    => 'subheading',
				'content' => __( 'Animation', 'wp-tabs-pro' ),
			),
			array(
				'id'         => 'sptpro_tabs_animation',
				'type'       => 'switcher',
				'title'      => __( 'Animation', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Enable/Disable animation for tabs content.', 'wp-tabs-pro' ),
				'title_help' => __( '<div class="wptabspro-info-label">Animation</div><div class="wptabspro-short-content">You can select animation to enhance your tab with over 50+ fascinating animations to add dynamic and eye-catching effects to your content.</div><a class="wptabspro-open-docs" href="https://docs.shapedplugin.com/docs/wp-tabs-pro/configurations/how-to-configure-tabs-animation/" target="_blank">Open Docs</a><a class="wptabspro-open-live-demo" href="https://wptabs.com/tabs-animation/" target="_blank">Live Demo</a>', 'wp-tabs-pro' ),
				'text_on'    => __( 'Enabled', 'wp-tabs-pro' ),
				'text_off'   => __( 'Disabled', 'wp-tabs-pro' ),
				'text_width' => 96,
				'default'    => false,
			),
			array(
				'id'         => 'sptpro_tabs_animation_type',
				'type'       => 'select',
				'title'      => __( 'Animation Style', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Choose an animation style for tabs content.', 'wp-tabs-pro' ),
				'options'    => array(
					'fadeIn'            => __( 'fadeIn', 'wp-tabs-pro' ),
					'fadeInDown'        => __( 'fadeInDown', 'wp-tabs-pro' ),
					'fadeInLeft'        => __( 'fadeInLeft', 'wp-tabs-pro' ),
					'fadeInRight'       => __( 'fadeInRight', 'wp-tabs-pro' ),
					'fadeInUp'          => __( 'fadeInUp', 'wp-tabs-pro' ),
					'fadeInDownBig'     => __( 'fadeInDownBig', 'wp-tabs-pro' ),
					'fadeInLeftBig'     => __( 'fadeInLeftBig', 'wp-tabs-pro' ),
					'fadeInRightBig'    => __( 'fadeInRightBig', 'wp-tabs-pro' ),
					'fadeInUpBig'       => __( 'fadeInUpBig', 'wp-tabs-pro' ),
					'zoomIn'            => __( 'zoomIn', 'wp-tabs-pro' ),
					'zoomInDown'        => __( 'zoomInDown', 'wp-tabs-pro' ),
					'zoomInLeft'        => __( 'zoomInLeft', 'wp-tabs-pro' ),
					'zoomInRight'       => __( 'zoomInRight', 'wp-tabs-pro' ),
					'zoomInUp'          => __( 'zoomInUp', 'wp-tabs-pro' ),
					'slideInDown'       => __( 'slideInDown', 'wp-tabs-pro' ),
					'slideInLeft'       => __( 'slideInLeft', 'wp-tabs-pro' ),
					'slideInRight'      => __( 'slideInRight', 'wp-tabs-pro' ),
					'slideInUp'         => __( 'slideInUp', 'wp-tabs-pro' ),
					'flip'              => __( 'flip', 'wp-tabs-pro' ),
					'flipInX'           => __( 'flipInX', 'wp-tabs-pro' ),
					'flipInY'           => __( 'flipInY', 'wp-tabs-pro' ),
					'bounce'            => __( 'bounce', 'wp-tabs-pro' ),
					'bounceIn'          => __( 'bounceIn', 'wp-tabs-pro' ),
					'bounceInLeft'      => __( 'bounceInLeft', 'wp-tabs-pro' ),
					'bounceInRight'     => __( 'bounceInRight', 'wp-tabs-pro' ),
					'bounceInUp'        => __( 'bounceInUp', 'wp-tabs-pro' ),
					'bounceInDown'      => __( 'bounceInDown', 'wp-tabs-pro' ),
					'rotateIn'          => __( 'rotateIn', 'wp-tabs-pro' ),
					'rotateInDownLeft'  => __( 'rotateInDownLeft', 'wp-tabs-pro' ),
					'rotateInDownRight' => __( 'rotateInDownRight', 'wp-tabs-pro' ),
					'rotateInUpLeft'    => __( 'rotateInUpLeft', 'wp-tabs-pro' ),
					'rotateInUpRight'   => __( 'rotateInUpRight', 'wp-tabs-pro' ),
					'flash'             => __( 'flash', 'wp-tabs-pro' ),
					'pulse'             => __( 'pulse', 'wp-tabs-pro' ),
					'shake'             => __( 'shake', 'wp-tabs-pro' ),
					'swing'             => __( 'swing', 'wp-tabs-pro' ),
					'tada'              => __( 'tada', 'wp-tabs-pro' ),
					'wobble'            => __( 'wobble', 'wp-tabs-pro' ),
					'rubberBand'        => __( 'rubberBand', 'wp-tabs-pro' ),
					'heartBeat'         => __( 'heartBeat', 'wp-tabs-pro' ),
					'jello'             => __( 'jello', 'wp-tabs-pro' ),
					'headShake'         => __( 'headShake', 'wp-tabs-pro' ),
					'lightSpeedIn'      => __( 'lightSpeedIn', 'wp-tabs-pro' ),
					'jackInTheBox'      => __( 'jackInTheBox', 'wp-tabs-pro' ),
					'rollIn'            => __( 'rollIn', 'wp-tabs-pro' ),
				),
				'default'    => 'fadeIn',
				'dependency' => array( 'sptpro_tabs_animation', '==', 'true' ),
			),
			array(
				'id'         => 'sptpro_animation_time',
				'type'       => 'spinner',
				'title'      => __( 'Transition Delay', 'wp-tabs-pro' ),
				'subtitle'   => __( 'Set animation transition delay in milisecond.', 'wp-tabs-pro' ),
				'unit'       => 'ms',
				'min'        => 10,
				'max'        => 100000,
				'default'    => 500,
				'dependency' => array( 'sptpro_tabs_animation', '==', 'true' ),
			),
		),
	),
); // Carousel settings section end.

	//
	// Typography section begin.
	//
	SP_WP_TABS::createSection(
		$sptpro_shortcode_settings,
		array(
			'title'           => __( 'Typography', 'wp-tabs-pro' ),
			'icon'            => 'fa fa-font',
			'enqueue_webfont' => true,
			'fields'          => array(
				array(
					'id'       => 'sptpro_section_title_font_load',
					'type'     => 'switcher',
					'title'    => __( 'Load Tabs Section Title Font', 'wp-tabs-pro' ),
					'subtitle' => __( 'On/Off google font for the section title.', 'wp-tabs-pro' ),
					'default'  => false,
				),
				array(
					'id'            => 'sptpro_section_title_typo',
					'type'          => 'typography',
					'class'         => 'sptpro_tabs_section_title_typo',
					'title'         => __( 'Tabs Section Title', 'wp-tabs-pro' ),
					'subtitle'      => __( 'Set tabs section title font properties.', 'wp-tabs-pro' ),
					'margin_bottom' => true,
					'default'       => array(
						'color'          => '#444444',
						'font-family'    => '',
						'font-weight'    => '600',
						'font-style'     => 'normal',
						'font-size'      => '28',
						'line-height'    => '28',
						'letter-spacing' => '0',
						'text-align'     => 'left',
						'text-transform' => 'none',
						'margin-bottom'  => '30',
						'type'           => 'google',
						'unit'           => 'px',
					),
					'preview'       => 'always',
					'preview_text'  => 'Tabs Section Title',
				),
				array(
					'id'       => 'sptpro_tabs_title_font_load',
					'type'     => 'switcher',
					'title'    => __( 'Load Tabs Title Font', 'wp-tabs-pro' ),
					'subtitle' => __( 'On/Off google font for the tabs title.', 'wp-tabs-pro' ),
					'default'  => false,
				),
				array(
					'id'           => 'sptpro_tabs_title_typo',
					'type'         => 'typography',
					'title'        => __( 'Tabs Title', 'wp-tabs-pro' ),
					'subtitle'     => __( 'Set tabs title font properties.', 'wp-tabs-pro' ),
					'default'      => array(
						'font-family'    => '',
						'font-weight'    => '600',
						'font-style'     => 'normal',
						'font-size'      => '16',
						'line-height'    => '22',
						'letter-spacing' => '0',
						'text-align'     => 'center',
						'text-transform' => 'none',
						'color'          => '#444',
						'hover_color'    => '#444',
						'active_color'   => '#444',
						'type'           => 'google',
					),
					'preview_text' => 'Tabs Title',
					'preview'      => 'always',
					'color'        => true,
					'hover_color'  => true,
					'active_color' => true,
				),
				array(
					'id'       => 'sptpro_subtitle_font_load',
					'type'     => 'switcher',
					'title'    => __( 'Load Subtitle Font', 'wp-tabs-pro' ),
					'subtitle' => __( 'On/Off google font for the tabs subtitle.', 'wp-tabs-pro' ),
					'default'  => false,
				),
				array(
					'id'           => 'sptpro_subtitle_typo',
					'type'         => 'typography',
					'title'        => __( 'Tabs Subtitle', 'wp-tabs-pro' ),
					'subtitle'     => __( 'Set tabs subtitle font properties.', 'wp-tabs-pro' ),
					'default'      => array(
						'font-family'    => '',
						'font-weight'    => '400',
						'font-style'     => 'normal',
						'font-size'      => '14',
						'line-height'    => '18',
						'letter-spacing' => '0',
						'color'          => '#616161',
						'active_color'   => '#616161',
						'hover_color'    => '#616161',
						'text-align'     => 'center',
						'text-transform' => 'none',
						'type'           => 'google',
					),
					'preview_text' => 'Tabs Sub Title',
					'preview'      => 'always',
					'color'        => true,
					'hover_color'  => true,
					'active_color' => true,
				),
				array(
					'id'       => 'sptpro_desc_font_load',
					'type'     => 'switcher',
					'title'    => __( 'Load Description Font', 'wp-tabs-pro' ),
					'subtitle' => __( 'On/Off google font for the tabs description.', 'wp-tabs-pro' ),
					'default'  => false,
				),
				array(
					'id'           => 'sptpro_desc_typo',
					'type'         => 'typography',
					'title'        => __( 'Description', 'wp-tabs-pro' ),
					'subtitle'     => __( 'Set description font properties.', 'wp-tabs-pro' ),
					'default'      => array(
						'color'          => '#444',
						'font-family'    => '',
						'font-weight'    => '400',
						'font-style'     => 'normal',
						'font-size'      => '16',
						'line-height'    => '24',
						'letter-spacing' => '0',
						'text-align'     => 'left',
						'text-transform' => 'none',
						'type'           => 'google',
					),
					'preview'      => 'always',
					'preview_text' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.',
				),
			), // End of fields array.
		)
	); // Style settings section end.


	//
	// Metabox of the footer section / shortocde section.
	// Set a unique slug-like ID.
	//
	$sptpro_display_shortcode = 'sp_tab_display_shortcode';

	//
	// Create a metabox.
	//
	SP_WP_TABS::createMetabox(
		$sptpro_display_shortcode,
		array(
			'title'     => 'WP Tabs Pro',
			'post_type' => 'sp_wp_tabs',
			'context'   => 'normal',
		)
	);

	//
	// Create a section.
	//
	SP_WP_TABS::createSection(
		$sptpro_display_shortcode,
		array(
			'fields' => array(
				array(
					'type'  => 'shortcode',
					'class' => 'sp-tab__admin-footer',
				),
			),
		)
	);
