<?php
/**
 * The background field of the plugin.
 *
 * @link https://shapedplugin.com
 * @since 2.0.11
 *
 * @package WP_Tabs_Pro
 * @subpackage WP_Tabs_Pro/admin
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
} // Cannot access directly.

if ( ! class_exists( 'SP_WP_TABS_Field_background' ) ) {
	/**
	 *
	 * Field: background
	 *
	 * @since 1.0.0
	 * @version 1.0.0
	 */
	class SP_WP_TABS_Field_background extends SP_WP_TABS_Fields {

		/**
		 * Field constructor.
		 *
		 * @param array  $field The field type.
		 * @param string $value The values of the field.
		 * @param string $unique The unique ID for the field.
		 * @param string $where To where show the output CSS.
		 * @param string $parent The parent args.
		 */
		public function __construct( $field, $value = '', $unique = '', $where = '', $parent = '' ) {
			parent::__construct( $field, $value, $unique, $where, $parent );
		}

		/**
		 * Render
		 *
		 * @return void
		 */
		public function render() {

			$args = wp_parse_args(
				$this->field,
				array(
					'background_color'              => true,
					'background_image'              => true,
					'background_position'           => true,
					'background_repeat'             => true,
					'background_attachment'         => true,
					'background_size'               => true,
					'background_origin'             => false,
					'background_clip'               => false,
					'background_blend_mode'         => false,
					'background_gradient'           => false,
					'background_gradient_color'     => true,
					'background_gradient_direction' => true,
					'background_image_preview'      => true,
					'background_auto_attributes'    => false,
					'background_image_library'      => 'image',
					'background_image_placeholder'  => esc_html__( 'No background selected', 'wp-tabs-pro' ),
				)
			);

			$default_value = array(
				'background-color'              => '',
				'background-image'              => '',
				'background-position'           => '',
				'background-repeat'             => '',
				'background-attachment'         => '',
				'background-size'               => '',
				'background-origin'             => '',
				'background-clip'               => '',
				'background-blend-mode'         => '',
				'background-gradient-color'     => '',
				'background-gradient-direction' => '',
			);

			$default_value = ( ! empty( $this->field['default'] ) ) ? wp_parse_args( $this->field['default'], $default_value ) : $default_value;

			$this->value = wp_parse_args( $this->value, $default_value );

			echo wp_kses_post( $this->field_before() );

			echo '<div class="wptabspro--background-colors">';

			//
			// Background Color.
			if ( ! empty( $args['background_color'] ) ) {

				echo '<div class="wptabspro--color">';

				echo ( ! empty( $args['background_gradient'] ) ) ? '<div class="wptabspro--title">' . esc_html__( 'From', 'wp-tabs-pro' ) . '</div>' : '';

				SP_WP_TABS::field(
					array(
						'id'      => 'background-color',
						'type'    => 'color',
						'default' => $default_value['background-color'],
					),
					$this->value['background-color'],
					$this->field_name(),
					'field/background'
				);

				echo '</div>';

			}

			//
			// Background Gradient Color.
			if ( ! empty( $args['background_gradient_color'] ) && ! empty( $args['background_gradient'] ) ) {

				echo '<div class="wptabspro--color">';

				echo ( ! empty( $args['background_gradient'] ) ) ? '<div class="wptabspro--title">' . esc_html__( 'To', 'wp-tabs-pro' ) . '</div>' : '';

				SP_WP_TABS::field(
					array(
						'id'      => 'background-gradient-color',
						'type'    => 'color',
						'default' => $default_value['background-gradient-color'],
					),
					$this->value['background-gradient-color'],
					$this->field_name(),
					'field/background'
				);

				echo '</div>';

			}

			//
			// Background Gradient Direction.
			if ( ! empty( $args['background_gradient_direction'] ) && ! empty( $args['background_gradient'] ) ) {

				echo '<div class="wptabspro--color">';

				echo ( ! empty( $args['background_gradient'] ) ) ? '<div class="wptabspro---title">' . esc_html__( 'Direction', 'wp-tabs-pro' ) . '</div>' : '';

				SP_WP_TABS::field(
					array(
						'id'      => 'background-gradient-direction',
						'type'    => 'select',
						'options' => array(
							// ''          => esc_html__( 'Select Gradient Direction', 'wp-tabs-pro' ),
							'to bottom' => esc_html__( '&#8659; top to bottom', 'wp-tabs-pro' ),
							'to right'  => esc_html__( '&#8658; left to right', 'wp-tabs-pro' ),
							'135deg'    => esc_html__( '&#8664; corner top to right', 'wp-tabs-pro' ),
							'-135deg'   => esc_html__( '&#8665; corner top to left', 'wp-tabs-pro' ),
						),
					),
					$this->value['background-gradient-direction'],
					$this->field_name(),
					'field/background'
				);

				echo '</div>';

			}

			echo '</div>';

			//
			// Background Image.
			if ( ! empty( $args['background_image'] ) ) {

				echo '<div class="wptabspro--background-image">';

				SP_WP_TABS::field(
					array(
						'id'          => 'background-image',
						'type'        => 'media',
						'class'       => 'wptabspro-assign-field-background',
						'library'     => $args['background_image_library'],
						'preview'     => $args['background_image_preview'],
						'placeholder' => $args['background_image_placeholder'],
						'attributes'  => array( 'data-depend-id' => $this->field['id'] ),
					),
					$this->value['background-image'],
					$this->field_name(),
					'field/background'
				);

				echo '</div>';

			}

			$auto_class   = ( ! empty( $args['background_auto_attributes'] ) ) ? ' wptabspro--auto-attributes' : '';
			$hidden_class = ( ! empty( $args['background_auto_attributes'] ) && empty( $this->value['background-image']['url'] ) ) ? ' wptabspro--attributes-hidden' : '';

			echo '<div class="wptabspro--background-attributes' . esc_attr( $auto_class . $hidden_class ) . '">';

			//
			// Background Position.
			if ( ! empty( $args['background_position'] ) ) {

				SP_WP_TABS::field(
					array(
						'id'      => 'background-position',
						'type'    => 'select',
						'options' => array(
							''              => esc_html__( 'Background Position', 'wp-tabs-pro' ),
							'left top'      => esc_html__( 'Left Top', 'wp-tabs-pro' ),
							'left center'   => esc_html__( 'Left Center', 'wp-tabs-pro' ),
							'left bottom'   => esc_html__( 'Left Bottom', 'wp-tabs-pro' ),
							'center top'    => esc_html__( 'Center Top', 'wp-tabs-pro' ),
							'center center' => esc_html__( 'Center Center', 'wp-tabs-pro' ),
							'center bottom' => esc_html__( 'Center Bottom', 'wp-tabs-pro' ),
							'right top'     => esc_html__( 'Right Top', 'wp-tabs-pro' ),
							'right center'  => esc_html__( 'Right Center', 'wp-tabs-pro' ),
							'right bottom'  => esc_html__( 'Right Bottom', 'wp-tabs-pro' ),
						),
					),
					$this->value['background-position'],
					$this->field_name(),
					'field/background'
				);

			}

			//
			// Background Repeat.
			if ( ! empty( $args['background_repeat'] ) ) {

				SP_WP_TABS::field(
					array(
						'id'      => 'background-repeat',
						'type'    => 'select',
						'options' => array(
							''          => esc_html__( 'Background Repeat', 'wp-tabs-pro' ),
							'repeat'    => esc_html__( 'Repeat', 'wp-tabs-pro' ),
							'no-repeat' => esc_html__( 'No Repeat', 'wp-tabs-pro' ),
							'repeat-x'  => esc_html__( 'Repeat Horizontally', 'wp-tabs-pro' ),
							'repeat-y'  => esc_html__( 'Repeat Vertically', 'wp-tabs-pro' ),
						),
					),
					$this->value['background-repeat'],
					$this->field_name(),
					'field/background'
				);

			}

			//
			// Background Attachment.
			if ( ! empty( $args['background_attachment'] ) ) {

				SP_WP_TABS::field(
					array(
						'id'      => 'background-attachment',
						'type'    => 'select',
						'options' => array(
							''       => esc_html__( 'Background Attachment', 'wp-tabs-pro' ),
							'scroll' => esc_html__( 'Scroll', 'wp-tabs-pro' ),
							'fixed'  => esc_html__( 'Fixed', 'wp-tabs-pro' ),
						),
					),
					$this->value['background-attachment'],
					$this->field_name(),
					'field/background'
				);

			}

			//
			// Background Size.
			if ( ! empty( $args['background_size'] ) ) {

				SP_WP_TABS::field(
					array(
						'id'      => 'background-size',
						'type'    => 'select',
						'options' => array(
							''        => esc_html__( 'Background Size', 'wp-tabs-pro' ),
							'cover'   => esc_html__( 'Cover', 'wp-tabs-pro' ),
							'contain' => esc_html__( 'Contain', 'wp-tabs-pro' ),
						),
					),
					$this->value['background-size'],
					$this->field_name(),
					'field/background'
				);

			}

			//
			// Background Origin.
			if ( ! empty( $args['background_origin'] ) ) {

				SP_WP_TABS::field(
					array(
						'id'      => 'background-origin',
						'type'    => 'select',
						'options' => array(
							''            => esc_html__( 'Background Origin', 'wp-tabs-pro' ),
							'padding-box' => esc_html__( 'Padding Box', 'wp-tabs-pro' ),
							'border-box'  => esc_html__( 'Border Box', 'wp-tabs-pro' ),
							'content-box' => esc_html__( 'Content Box', 'wp-tabs-pro' ),
						),
					),
					$this->value['background-origin'],
					$this->field_name(),
					'field/background'
				);

			}

			//
			// Background Clip.
			if ( ! empty( $args['background_clip'] ) ) {

				SP_WP_TABS::field(
					array(
						'id'      => 'background-clip',
						'type'    => 'select',
						'options' => array(
							''            => esc_html__( 'Background Clip', 'wp-tabs-pro' ),
							'border-box'  => esc_html__( 'Border Box', 'wp-tabs-pro' ),
							'padding-box' => esc_html__( 'Padding Box', 'wp-tabs-pro' ),
							'content-box' => esc_html__( 'Content Box', 'wp-tabs-pro' ),
						),
					),
					$this->value['background-clip'],
					$this->field_name(),
					'field/background'
				);

			}

			//
			// Background Blend Mode.
			if ( ! empty( $args['background_blend_mode'] ) ) {

				SP_WP_TABS::field(
					array(
						'id'      => 'background-blend-mode',
						'type'    => 'select',
						'options' => array(
							''            => esc_html__( 'Background Blend Mode', 'wp-tabs-pro' ),
							'normal'      => esc_html__( 'Normal', 'wp-tabs-pro' ),
							'multiply'    => esc_html__( 'Multiply', 'wp-tabs-pro' ),
							'screen'      => esc_html__( 'Screen', 'wp-tabs-pro' ),
							'overlay'     => esc_html__( 'Overlay', 'wp-tabs-pro' ),
							'darken'      => esc_html__( 'Darken', 'wp-tabs-pro' ),
							'lighten'     => esc_html__( 'Lighten', 'wp-tabs-pro' ),
							'color-dodge' => esc_html__( 'Color Dodge', 'wp-tabs-pro' ),
							'saturation'  => esc_html__( 'Saturation', 'wp-tabs-pro' ),
							'color'       => esc_html__( 'Color', 'wp-tabs-pro' ),
							'luminosity'  => esc_html__( 'Luminosity', 'wp-tabs-pro' ),
						),
					),
					$this->value['background-blend-mode'],
					$this->field_name(),
					'field/background'
				);

			}

			echo '</div>';

			echo wp_kses_post( $this->field_after() );

		}

	}
}
