<?php
/**
 * The icon field of the plugin.
 *
 * @link       https://shapedplugin.com/
 * @since      1.0.0
 *
 * @package    WP_Tabs_Pro
 * @subpackage WP_Tabs_Pro/admin
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
} // Cannot access directly.

if ( ! class_exists( 'SP_WP_TABS_Field_icon' ) ) {
	/**
	 *
	 * Field: icon
	 *
	 * @since 1.0.0
	 * @version 1.0.0
	 */
	class SP_WP_TABS_Field_icon extends SP_WP_TABS_Fields {
		/**
		 * The class constructor.
		 *
		 * @param array  $field The field type.
		 * @param string $value The values of the field.
		 * @param string $unique The unique ID for the field.
		 * @param string $where To where show the output CSS.
		 * @param string $parent The parent args.
		 */
		public function __construct( $field, $value = '', $unique = '', $where = '', $parent = '' ) {
			parent::__construct( $field, $value, $unique, $where, $parent );
		}

		/**
		 * Render
		 *
		 * @return void
		 */
		public function render() {

			$args = wp_parse_args(
				$this->field,
				array(
					'button_title' => esc_html__( 'Add Icon', 'wp-tabs-pro' ),
					'remove_title' => esc_html__( 'Remove Icon', 'wp-tabs-pro' ),
				)
			);

			echo wp_kses_post( $this->field_before() );

			$nonce      = wp_create_nonce( 'wptabspro_icon_nonce' );
			$icon_value = is_string( $this->value ) ? $this->value : '';
			$hidden     = ( empty( $icon_value ) ) ? ' hidden' : '';
			echo '<div class="wptabspro-icon-select">';
			echo '<span class="wptabspro-icon-preview' . esc_attr( $hidden ) . '"><i class="' . esc_attr( $icon_value ) . '"></i></span>';
			echo '<a href="#" class="button button-primary wptabspro-icon-add" data-nonce="' . esc_attr( $nonce ) . '">' . wp_kses_post( $args['button_title'] ) . '</a>';
			echo '<a href="#" class="button wptabspro-warning-primary wptabspro-icon-remove' . esc_attr( $hidden ) . '">' . wp_kses_post( $args['remove_title'] ) . '</a>';
			echo '<input type="text" name="' . esc_attr( $this->field_name() ) . '" value="' . esc_attr( $icon_value ) . '" class="wptabspro-icon-value"' . $this->field_attributes() . ' />';// phpcs:ignore
			echo '</div>';

			echo wp_kses_post( $this->field_after() );

		}

	}
}
