<?php
/**
 * The admin action functionality of the plugin.
 *
 * @link       https://shapedplugin.com/
 * @since      1.0.0
 *
 * @package    WP_Tabs_Pro
 * @subpackage WP_Tabs_Pro/admin
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
} // Cannot access directly.

/**
 * Populate the taxonomy name list to he select option.
 *
 * @return void
 */
function sp_tabs_get_taxonomies() {
	extract( $_REQUEST );
	$taxonomy_names = get_object_taxonomies( array( 'post_type' => $sptpro_post_type ), 'names' );
	echo '<option value="">Select Taxonomy</option>';
	foreach ( $taxonomy_names as $key => $label ) {
		echo '<option value="' . esc_attr( $label ) . '">' . esc_html( $label ) . '</option>';
	}
	die( 0 );
}
add_action( 'wp_ajax_sp_tabs_get_taxonomies', 'sp_tabs_get_taxonomies' );

/**
 * Populate the taxonomy terms list to the select option.
 *
 * @return void
 */
function sp_tabs_get_terms() {
	extract( $_REQUEST );
	$terms = get_terms( $sptpro_post_taxonomy );
	foreach ( $terms as $key => $value ) {
		echo '<option value="' . esc_attr( $value->term_id ) . '">' . esc_html( $value->name ) . '</option>';
	}
	die( 0 );
}
add_action( 'wp_ajax_sp_tabs_get_terms', 'sp_tabs_get_terms' );

/**
 * Get specific post to the select box.
 *
 * @return void
 */
function sp_tabs_get_posts() {
	extract( $_REQUEST );
	$all_posts = get_posts(
		array(
			'post_type'      => $sptpro_post_type,
			'posts_per_page' => -1,
		)
	);
	foreach ( $all_posts as $key => $post_obj ) {
		echo '<option value="' . esc_attr( $post_obj->ID ) . '">' . wp_kses_post( $post_obj->post_title ) . '</option>';
	}
	die( 0 );
}
add_action( 'wp_ajax_sp_tabs_get_posts', 'sp_tabs_get_posts' );


if ( ! function_exists( 'wptabspro_get_icons' ) ) {
	/**
	 *
	 * Get icons from admin ajax
	 *
	 * @since 1.0.0
	 * @version 1.0.0
	 */
	function wptabspro_get_icons() {

		$nonce = ( ! empty( $_POST['nonce'] ) ) ? sanitize_text_field( wp_unslash( $_POST['nonce'] ) ) : '';

		if ( ! wp_verify_nonce( $nonce, 'wptabspro_icon_nonce' ) ) {
			wp_send_json_error( array( 'error' => esc_html__( 'Error: Nonce verification has failed. Please try again.', 'wp-tabs-pro' ) ) );
		}

		ob_start();

		$icon_library = ( apply_filters( 'wptabspro_fa4', false ) ) ? 'fa4' : 'fa5';

		SP_WP_TABS::include_plugin_file( 'fields/icon/' . $icon_library . '-icons.php' );

		$icon_lists = apply_filters( 'wptabspro_add_custom_icons', wptabspro_get_default_icons() );

		if ( ! empty( $icon_lists ) ) {

			foreach ( $icon_lists as $list ) {

				echo ( count( $icon_lists ) >= 2 ) ? '<div class="wptabspro-icon-title">' . esc_attr( $list['title'] ) . '</div>' : '';

				foreach ( $list['icons'] as $icon ) {
					echo '<i title="' . esc_attr( $icon ) . '" class="' . esc_attr( $icon ) . '"></i>';
				}
			}
		} else {

				echo '<div class="wptabspro-text-error">' . esc_html__( 'No data provided by developer', 'wp-tabs-pro' ) . '</div>';

		}

		$content = ob_get_clean();

		wp_send_json_success( array( 'content' => $content ) );

	}
	add_action( 'wp_ajax_wptabspro-get-icons', 'wptabspro_get_icons' );
}

if ( ! function_exists( 'wptabspro_reset_ajax' ) ) {
	/**
	 *
	 * Reset Ajax
	 *
	 * @since 1.0.0
	 * @version 1.0.0
	 */
	function wptabspro_reset_ajax() {

		$nonce  = ( ! empty( $_POST['nonce'] ) ) ? sanitize_text_field( wp_unslash( $_POST['nonce'] ) ) : '';
		$unique = ( ! empty( $_POST['unique'] ) ) ? sanitize_text_field( wp_unslash( $_POST['unique'] ) ) : '';

		if ( ! wp_verify_nonce( $nonce, 'wptabspro_backup_nonce' ) ) {
			wp_send_json_error( array( 'error' => esc_html__( 'Error: Nonce verification has failed. Please try again.', 'wp-tabs-pro' ) ) );
		}

		// Success.
		delete_option( $unique );

		wp_send_json_success();

	}
	add_action( 'wp_ajax_wptabspro-reset', 'wptabspro_reset_ajax' );
}


if ( ! function_exists( 'wptabspro_chosen_ajax' ) ) {
	/**
	 *
	 * Chosen Ajax
	 *
	 * @since 1.0.0
	 * @version 1.0.0
	 */
	function wptabspro_chosen_ajax() {

		$nonce = ( ! empty( $_POST['nonce'] ) ) ? sanitize_text_field( wp_unslash( $_POST['nonce'] ) ) : '';
		$type  = ( ! empty( $_POST['type'] ) ) ? sanitize_text_field( wp_unslash( $_POST['type'] ) ) : '';
		$term  = ( ! empty( $_POST['term'] ) ) ? sanitize_text_field( wp_unslash( $_POST['term'] ) ) : '';
		$query = ( ! empty( $_POST['query_args'] ) ) ? wp_kses_post_deep( $_POST['query_args'] ) : array();

		if ( ! wp_verify_nonce( $nonce, 'wptabspro_chosen_ajax_nonce' ) ) {
			wp_send_json_error( array( 'error' => esc_html__( 'Error: Nonce verification has failed. Please try again.', 'wp-tabs-pro' ) ) );
		}

		if ( empty( $type ) || empty( $term ) ) {
			wp_send_json_error( array( 'error' => esc_html__( 'Error: Missing request arguments.', 'wp-tabs-pro' ) ) );
		}

		$capability = apply_filters( 'wptabspro_chosen_ajax_capability', 'manage_options' );

		if ( ! current_user_can( $capability ) ) {
			wp_send_json_error( array( 'error' => esc_html__( 'You do not have required permissions to access.', 'wp-tabs-pro' ) ) );
		}

		// Success.
		$options = SP_WP_TABS_Fields::field_data( $type, $term, $query );

		wp_send_json_success( $options );

	}
	add_action( 'wp_ajax_wptabspro-chosen', 'wptabspro_chosen_ajax' );
}


if ( ! function_exists( 'wptabspro_set_icons' ) ) {
	/**
	 *
	 * Set icons for wp dialog
	 *
	 * @since 1.0.0
	 * @version 1.0.0
	 */
	function wptabspro_set_icons() {
		$current_screen            = get_current_screen();
			$the_current_post_type = $current_screen->post_type;
		if ( 'sp_wp_tabs' === $the_current_post_type ) {
			?>
		<div id="wptabspro-modal-icon" class="wptabspro-modal wptabspro-modal-icon">
		<div class="wptabspro-modal-table">
			<div class="wptabspro-modal-table-cell">
			<div class="wptabspro-modal-overlay"></div>
			<div class="wptabspro-modal-inner">
				<div class="wptabspro-modal-title">
				<?php esc_html_e( 'Add Icon', 'wp-tabs-pro' ); ?>
				<div class="wptabspro-modal-close wptabspro-icon-close"></div>
				</div>
				<div class="wptabspro-modal-header wptabspro-text-center">
				<input type="text" placeholder="<?php esc_html_e( 'Search a Icon...', 'wp-tabs-pro' ); ?>" class="wptabspro-icon-search" />
				</div>
				<div class="wptabspro-modal-content">
				<div class="wptabspro-modal-loading"><div class="wptabspro-loading"></div></div>
				<div class="wptabspro-modal-load"></div>
				</div>
			</div>
			</div>
		</div>
		</div>
			<?php
		}
	}
	add_action( 'admin_footer', 'wptabspro_set_icons' );
}

add_filter( 'wptabspro_fa4', '__return_true' );
