<?php
/**
 * The settings options of the plugin.
 *
 * @link       https://shapedplugin.com/
 * @since      1.0.0
 *
 * @package    WP_Tabs_Pro
 * @subpackage WP_Tabs_Pro/admin
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
} // Cannot access directly.

//
// Set a unique slug-like ID.
//
$prefix = 'sp-tab__settings';

//
// Create options.
//
SP_WP_TABS::createOptions(
	$prefix,
	array(
		'menu_title'         => __( 'Settings', 'wp-tabs-pro' ),
		'menu_slug'          => 'tabs_settings',
		'menu_parent'        => 'edit.php?post_type=sp_wp_tabs',
		'menu_type'          => 'submenu',
		'show_bar_menu'      => false,
		'ajax_save'          => true,
		'save_defaults'      => true,
		'show_reset_all'     => false,
		'show_all_options'   => false,
		'show_reset_section' => true,
		'show_search'        => false,
		'show_footer'        => false,
		'framework_title'    => __( 'Settings', 'wp-tabs-pro' ),
		'framework_class'    => 'sp-tab__options',
		'theme'              => 'light',
		// 'async_webfont'   => true,
	)
);

//
// License key section.
//
SP_WP_TABS::createSection(
	$prefix,
	array(
		'title'  => __( 'License Key', 'wp-tabs-pro' ),
		'icon'   => 'fa fa-key',

		'fields' => array(
			array(
				'id'   => 'license_key',
				'type' => 'license',
			),
		),
	)
);

//
// Create a section.
//
SP_WP_TABS::createSection(
	$prefix,
	array(
		'title'  => __( 'Advanced Settings', 'wp-tabs-pro' ),
		'icon'   => 'fa fa-cogs',
		'fields' => array(
			array(
				'id'         => 'sptpro_data_remove',
				'type'       => 'checkbox',
				'title'      => __( 'Clean-up Data on Deletion', 'wp-tabs-pro' ),
				'title_help' => __( 'Check this box if you would like Wp Tabs Pro to completely remove all of its data when the plugin is deleted.', 'wp-tabs-pro' ),
				'default'    => false,
			),
			array(
				'id'         => 'sptpro_dequeue_google_font',
				'type'       => 'switcher',
				'title'      => __( 'Google Fonts', 'wp-tabs-pro' ),
				'default'    => false,
				'text_on'    => __( 'ENQUEUE', 'wp-tabs-pro' ),
				'text_off'   => __( 'DEQUEUE', 'wp-tabs-pro' ),
				'text_width' => 100,
			),
			array(
				'type'    => 'subheading',
				'content' => __( 'Enqueue or Dequeue CSS', 'wp-tabs-pro' ),
			),
			array(
				'id'         => 'sptpro_dequeue_fa_css',
				'type'       => 'switcher',
				'title'      => __( 'Font Awesome CSS', 'wp-tabs-pro' ),
				'default'    => true,
				'text_on'    => __( 'ENQUEUE', 'wp-tabs-pro' ),
				'text_off'   => __( 'DEQUEUE', 'wp-tabs-pro' ),
				'text_width' => 100,
			),
			array(
				'id'         => 'sptpro_dequeue_animation_css',
				'type'       => 'switcher',
				'title'      => __( 'Animation CSS', 'wp-tabs-pro' ),
				'default'    => true,
				'text_on'    => __( 'ENQUEUE', 'wp-tabs-pro' ),
				'text_off'   => __( 'DEQUEUE', 'wp-tabs-pro' ),
				'text_width' => 100,
			),
		),
	)
);

//
// WooCommerce Settings section.
//
SP_WP_TABS::createSection(
	$prefix,
	array(
		'title'  => __( 'Woo Tab Settings', 'wp-tabs-pro' ),
		'icon'   => 'fa fa-shopping-bag',

		'fields' => array(
			array(
				'type'    => 'submessage',
				'content' => __( 'Note: <a href="https://wordpress.org/plugins/woocommerce/" target="_blank">WooCommerce</a> is required to use this feature.', 'wp-tabs-pro' ),
				'style'   => 'warning',
			),
			array(
				'id'         => 'sptpro_woo_tab',
				'type'       => 'switcher',
				'title'      => __( 'WooCommerce Additional Tabs', 'wp-tabs-pro' ),
				'default'    => false,
				'text_on'    => __( 'Enabled', 'wp-tabs-pro' ),
				'text_off'   => __( 'Disabled', 'wp-tabs-pro' ),
				'text_width' => 100,
			),
			array(
				'id'         => 'sptpro_woo_set_tab',
				'type'       => 'group',
				'title'      => 'Additional Tabs',
				'fields'     => array(
					array(
						'id'      => 'sptpro_display_tab_for',
						'type'    => 'select',
						'title'   => __( 'Display Tabs on', 'wp-tabs-pro' ),
						'options' => array(
							'all'               => __( 'All Products', 'wp-tabs-pro' ),
							'taxonomy'          => __( 'Category', 'wp-tabs-pro' ),
							'Specific_Products' => __( 'Specific Products', 'wp-tabs-pro' ),
						),
						'default' => 'latest',
						'class'   => 'chosen',
					),
					array(
						'id'          => 'sptpro_specific_product',
						'type'        => 'select',
						'title'       => __( 'Specific Product(s)', 'wp-tabs-pro' ),
						'options'     => 'posts',
						'query_args'  => array(
							'post_type'      => 'product',
							'orderby'        => 'post_date',
							'order'          => 'DESC',
							'numberposts'    => 3000,
							'posts_per_page' => 3000,
							'cache_results'  => false,
							'no_found_rows'  => true,
						),
						'chosen'      => true,
						'sortable'    => true,
						'multiple'    => true,
						'placeholder' => __( 'Choose Product', 'wp-tabs-pro' ),
						'dependency'  => array( 'sptpro_display_tab_for', '==', 'Specific_Products' ),
					),
					array(
						'id'          => 'sptpro_taxonomy_terms',
						'type'        => 'select',
						'class'       => 'sptpro_taxonomy_terms',
						'title'       => __( 'Category Term(s)', 'wp-tabs-pro' ),
						'options'     => 'sp_wp_tabs_subcategory',
						'chosen'      => true,
						'sortable'    => true,
						'multiple'    => true,
						'placeholder' => __( 'Choose term(s)', 'wp-tabs-pro' ),
						'dependency'  => array( 'sptpro_display_tab_for', '==', 'taxonomy' ),
						'attributes'  => array(
							'style' => 'min-width: 250px;',
						),
					),
					array(
						'id'         => 'sptpro_woo_tab_shortcode',
						'type'       => 'select',
						'title'      => __( 'Select Tabs Group(s)', 'wp-tabs-pro' ),
						'options'    => 'shortcode_list',
						'query_args' => array(
							'post_type'      => 'sp_wp_tabs',
							'orderby'        => 'post_date',
							'order'          => 'DESC',
							'posts_per_page' => 100,
						),
						'chosen'     => true,
						'sortable'   => true,
						'multiple'   => true,
					),
					array(
						'id'      => 'sptpro_woo_tab_label_priority',
						'type'    => 'spinner',
						'class'   => 'sptpro_woo_tab_label_priority',
						'title'   => __( 'Tabs Priority', 'wp-tabs-pro' ),
						'default' => '50',
					),
				),
				'dependency' => array( 'sptpro_woo_tab', '==', true ),
				'attributes' => array(
					'style' => 'max-width: 250px;',
				),
			),
		),
	)
);

//
// Custom CSS Fields.
//
SP_WP_TABS::createSection(
	$prefix,
	array(
		'id'     => 'custom_css_section',
		'title'  => __( 'Additional CSS & JS', 'wp-tabs-pro' ),
		'icon'   => 'fa fa-css3',
		'fields' => array(
			array(
				'id'       => 'sptpro_custom_css',
				'type'     => 'code_editor',
				'title'    => __( 'Custom CSS', 'wp-tabs-pro' ),
				'settings' => array(
					'mode'  => 'css',
					'theme' => 'monokai',
				),
			),
			array(
				'id'       => 'sptpro_custom_js',
				'type'     => 'code_editor',
				'title'    => __( 'Custom JS', 'wp-tabs-pro' ),
				'settings' => array(
					'icon'  => 'fa fa-sliders',
					'theme' => 'monokai',
					'mode'  => 'javascript',
				),
			),
		),
	)
);
