<?php
/**
 * The admin preview.
 *
 * @link       https://shapedplugin.com/
 * @since      2.0.10
 *
 * @package    WP_Tabs_Pro
 * @subpackage WP_Tabs_Pro/admin
 */

/**
 * The admin preview.
 */
class WP_Tabs_Pro_Preview {
	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    2.0.10
	 */
	public function __construct() {
		$this->wp_tabs_pro_preview_action();
	}

	/**
	 * Public Action
	 *
	 * @return void
	 */
	private function wp_tabs_pro_preview_action() {
		// admin Preview.
		add_action( 'wp_ajax_sp_tab_preview_meta_box', array( $this, 'wp_tabs_pro_backend_preview' ) );

	}

	/**
	 * Function Backed preview.
	 *
	 * @since 2.0.10
	 */
	public function wp_tabs_pro_backend_preview() {
		$nonce = isset( $_POST['ajax_nonce'] ) ? sanitize_text_field( wp_unslash( $_POST['ajax_nonce'] ) ) : '';// phpcs:ignore
		if ( ! wp_verify_nonce( $nonce, 'wptabspro_metabox_nonce' ) ) {
			return;
		}

		$setting = array();
		// XSS ok.
		// No worries, This "POST" requests is sanitizing in the below array map.
		$data = ! empty( $_POST['data'] ) ? wp_unslash( $_POST['data'] )  : ''; // phpcs:ignore
		parse_str( $data, $setting );
		// Preset Layouts.
		$post_id                  = $setting['post_ID'];
		$sptpro_data_src          = $setting['sp_tab_source_options'];
		$sptpro_shortcode_options = $setting['sp_tab_shortcode_options'];
		$sptpro_data_upload       = get_post_meta( $post_id, 'sp_tab_source_options', true );
		$main_section_title       = $setting['post_title'];

		$sptpro_dynamic_style = '';
		$dynamic_style        = '';
		$sptpro_typography    = array();
		include WP_TABS_PRO_PATH . 'public/dynamic_style.php';
		// Custom CSS loads.
		$settings              = get_option( 'sp-tab__settings' );
		$custom_style          = isset( $settings['sptpro_custom_css'] ) ? trim( html_entity_decode( $settings['sptpro_custom_css'] ) ) : '';
		$sptpro_dynamic_style .= $custom_style;
		$dynamic_style        .= '<style id="sp_tabs_preview_dynamic_style">' . $sptpro_dynamic_style . '</style>';

		if ( $sptpro_dequeue_google_font ) {
			$enqueue_fonts = WP_Tabs_Pro_Public::load_google_fonts( $sptpro_typography );
			if ( ! empty( $enqueue_fonts ) ) {
				echo '<link rel="stylesheet" href="' . esc_url( add_query_arg( 'family', rawurlencode( implode( '|', $enqueue_fonts ) ), '//fonts.googleapis.com/css' ) ) . '" media="all">'; // phpcs:ignore
			}
		}
		echo $dynamic_style; // phpcs:ignore
		WP_Tabs_Pro_Shortcode::sp_tab_html_show( $post_id, $sptpro_data_src, $sptpro_shortcode_options, $main_section_title );
		?>
		<script src="<?php echo esc_url( WP_TABS_PRO_URL . 'public/js/wp-tabs-pro-public.min.js' ); ?>" ></script>
		<?php
		die();
	}

}
new WP_Tabs_Pro_Preview();
