<?php
/**
 * Admin Submenu of the Plugin
 *
 * @link       https://shapedplugin.com/
 * @since      1.0.0
 *
 * @package    WP_Tabs_Pro
 * @subpackage WP_Tabs_Pro/includes
 */

/**
 * Admin Submenu of the Plugin
 */
class WP_Tabs_Pro_Admin_Menu {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Admin help page
	 *
	 * @since    1.0.0
	 */
	public function sptpro_help_admin_submenu() {
		add_submenu_page(
			'edit.php?post_type=sp_wp_tabs',
			__( 'Help', 'wp-tabs-pro' ),
			__( 'Help', 'wp-tabs-pro' ),
			'manage_options',
			'tabs_help',
			array( $this, 'sptpro_help_callback' )
		);
	}

	/**
	 * Admin help callback function
	 *
	 * @since    1.0.0
	 */
	public function sptpro_help_callback() {

		include_once WP_TABS_PRO_PATH . 'admin/partials/tabs-pro-admin-display.php';
	}

	/**
	 * Add plugin action menu
	 *
	 * @param array $links The action link.
	 * @param array $file The file link.
	 *
	 * @return array
	 */
	public function sptpro_plugin_action_links( $links, $file ) {

		$manage_license     = new WP_Tabs_Pro_License( WP_TABS_PRO_FILE, WP_TABS_PRO_VERSION, 'ShapedPlugin', WP_TABS_PRO_STORE_URL, WP_TABS_PRO_ITEM_ID, WP_TABS_PRO_ITEM_SLUG );
		$license_key_status = $manage_license->get_license_status();
		$license_status     = ( is_object( $license_key_status ) ? $license_key_status->license : '' );

		if ( WP_TABS_PRO_BASENAME === $file ) {
			if ( 'valid' == $license_status ) {
				$new_links = array(
					sprintf( '<a href="%s">%s</a>', admin_url( 'post-new.php?post_type=sp_wp_tabs' ), __( 'Add Tab Group', 'wp-tabs-pro' ) ),
				);
			} else {
				$new_links = array(
					sprintf( '<a style="color: red; font-weight: 600;" href="%s">%s</a>', admin_url( 'edit.php?post_type=sp_wp_tabs&page=tabs_settings#tab=1' ), __( 'Activate license', 'wp-tabs-pro' ) ),
				);
			}
			return array_merge( $new_links, $links );
		}

		return $links;
	}

	/**
	 * Bottom review notice.
	 *
	 * @param string $text The review notice.
	 * @return string
	 */
	public function sptpro_review_text( $text ) {
		$screen = get_current_screen();
		if ( 'sp_wp_tabs' === get_post_type() || ( 'sp_wp_tabs_page_tabs_settings' === $screen->id ) || ( 'sp_wp_tabs_page_tabs_help' === $screen->id ) ) {
			$url  = 'https://wordpress.org/support/plugin/wp-expand-tabs-free/reviews/?filter=5#new-post';
			$text = sprintf( __( 'If you like <strong>WP Tabs Pro</strong>, please leave us a <a href="%s" target="_blank">&#9733;&#9733;&#9733;&#9733;&#9733;</a> rating. Your Review is very important to us as it helps us to grow more. ', 'wp-tabs-pro' ), $url );
		}

		return $text;
	}

}
