<?php
/**
 * The file that defines the WP Tabs Pro Woo Feature
 *
 * @link http://shapedplugin.com
 * @since 2.0.2
 *
 * @package    WP_Tabs_Pro
 * @subpackage WP_Tabs_Pro/includes
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
/**
 * Custom post class to register the Product tab.
 */
class WP_Tabs_Pro_Product_Tab {

	/**
	 * The single instance of the class.
	 *
	 * @var self
	 * @since 2.0.2
	 */
	private static $instance;

	/**
	 * Path to the file.
	 *
	 * @since 2.0.2
	 *
	 * @var string
	 */
	public $file = __FILE__;

	/**
	 * Sptpro_woo_set_tab.
	 *
	 * @var string
	 */
	public $sptpro_woo_set_tab = 'latest';

	/**
	 * Holds the base class object.
	 *
	 * @since 2.0.2
	 *
	 * @var object
	 */
	public $base;

	/**
	 *
	 * WooCommerce product tab construct function.
	 *
	 * @param string $sptpro_woo_set_tab set tab.
	 */
	public function __construct( $sptpro_woo_set_tab ) {
		$this->sptpro_woo_set_tab = $sptpro_woo_set_tab;
	}

	/**
	 *
	 * WooCommerce faq tab.
	 *
	 * @return array $tabs
	 * @param array $tabs woo tab.
	 */
	public function sptpro_woo_tab( $tabs ) {
		global $product;

		$sptpro_woo_set_tab     = $this->sptpro_woo_set_tab;
		$sptpro_display_tab_for = $sptpro_woo_set_tab['sptpro_display_tab_for'];

		$product_id = method_exists( $product, 'get_id' ) === true ? $product->get_id() : $product->ID;

		$cat_ids = get_the_terms( $product_id, 'product_cat' );
		$cat_ids = wp_list_pluck( $cat_ids, 'term_id' );

		$sptp_cat         = isset( $sptpro_woo_set_tab['sptpro_taxonomy_terms'] ) ? array_map( 'intval', $sptpro_woo_set_tab['sptpro_taxonomy_terms'] ) : array();
		$sptp_product_ids = isset( $sptpro_woo_set_tab['sptpro_specific_product'] ) ? array_map( 'intval', $sptpro_woo_set_tab['sptpro_specific_product'] ) : array();

		if ( ( is_array( $cat_ids ) && array_intersect( $sptp_cat, $cat_ids ) && 'taxonomy' === $sptpro_display_tab_for ) || 'all' === $sptpro_display_tab_for || ( 'Specific_Products' === $sptpro_display_tab_for && is_array( $sptp_product_ids ) ) && in_array( $product_id, $sptp_product_ids ) ) {

			$sptpro_tab_priority = isset( $sptpro_woo_set_tab['sptpro_woo_tab_label_priority'] ) ? $sptpro_woo_set_tab['sptpro_woo_tab_label_priority'] : '35';

			$sptpro_woo_tab_shortcode_ids = isset( $sptpro_woo_set_tab['sptpro_woo_tab_shortcode'] ) ? $sptpro_woo_set_tab['sptpro_woo_tab_shortcode'] : array();

			if ( ! empty( $sptpro_woo_tab_shortcode_ids ) ) {
				foreach ( $sptpro_woo_tab_shortcode_ids as $key => $sptpro_woo_tab_shortcode_id ) {

					$sptpro_data_src = get_post_meta( $sptpro_woo_tab_shortcode_id, 'sp_tab_source_options', true );
					$sptpro_tab_type = ( isset( $sptpro_data_src['sptpro_tab_type'] ) ? $sptpro_data_src['sptpro_tab_type'] : '' );
					$sptpro_data_src = isset( $sptpro_data_src['sptpro_content_source'] ) ? $sptpro_data_src['sptpro_content_source'] : '';

					if ( 'content-tabs' === $sptpro_tab_type && ! empty( $sptpro_data_src ) ) {
						foreach ( $sptpro_data_src as $key => $sptpro_tab ) {

							if ( ! is_array( $sptpro_tab ) ) {
								$sptpro_tab = array();
							}
							$sptpro_tab_priority++;

							if ( ! empty( $sptpro_tab ) && is_array( $sptpro_tab ) ) {
								$tabs[ 'sptpro_tab_' . $sptpro_tab_priority . $key ] = array(
									'title'    => __( $sptpro_tab['tabs_content_title'], 'woocommerce' ),
									'priority' => $sptpro_tab_priority,
									'callback' => array( $this, 'sptpro_product_tabs_panel_content' ),
									'content'  => $sptpro_tab['tabs_content_description'],
								);
							}
						}
					} elseif ( 'post-tabs' === $sptpro_tab_type ) {
						$sptpro_post_data_src      = get_post_meta( $sptpro_woo_tab_shortcode_id, 'sp_tab_source_options', true );
						$sptpro_post_type          = ( isset( $sptpro_post_data_src['sptpro_post_type'] ) ? $sptpro_post_data_src['sptpro_post_type'] : 'post' );
						$sptpro_display_posts_from = ( isset( $sptpro_post_data_src['sptpro_display_posts_from'] ) ? $sptpro_post_data_src['sptpro_display_posts_from'] : '' );
						$sptpro_post_taxonomy      = ( isset( $sptpro_post_data_src['sptpro_post_taxonomy'] ) ? $sptpro_post_data_src['sptpro_post_taxonomy'] : '' );
						$sptpro_taxonomy_terms     = ( isset( $sptpro_post_data_src['sptpro_taxonomy_terms'] ) ? $sptpro_post_data_src['sptpro_taxonomy_terms'] : '' );
						$sptpro_taxonomy_operator  = ( isset( $sptpro_post_data_src['taxonomy_operator'] ) ? $sptpro_post_data_src['taxonomy_operator'] : '' );
						$sptpro_specific_posts     = ( isset( $sptpro_post_data_src['sptpro_specific_posts'] ) ? $sptpro_post_data_src['sptpro_specific_posts'] : '' );
						$number_of_total_posts     = ( isset( $sptpro_post_data_src['number_of_total_posts'] ) ? $sptpro_post_data_src['number_of_total_posts'] : '' );
						$post_order_by             = ( isset( $sptpro_post_data_src['post_order_by'] ) ? $sptpro_post_data_src['post_order_by'] : 'date' );
						$post_order                = ( isset( $sptpro_post_data_src['post_order'] ) ? $sptpro_post_data_src['post_order'] : 'DESC' );

						if ( empty( $sptpro_post_type ) ) {
							return;
						}
						$args = array(
							'post_type'           => $sptpro_post_type,
							'post_status'         => 'publish',
							'ignore_sticky_posts' => 1,
							'posts_per_page'      => $number_of_total_posts,
							'orderby'             => $post_order_by,
							'order'               => $post_order,
						);
						if ( 'specific_post' === $sptpro_display_posts_from ) {
							$sptpro_get_specific = array(
								'post__in'       => $sptpro_specific_posts,
								'posts_per_page' => -1,
							);
							$args                = array_merge( $args, $sptpro_get_specific );
						}
						if ( 'taxonomy' === $sptpro_display_posts_from && ! empty( $sptpro_post_taxonomy ) && ! empty( $sptpro_taxonomy_terms ) ) {
							$args['tax_query'][] = array(
								'taxonomy' => $sptpro_post_taxonomy,
								'field'    => 'term_id',
								'terms'    => $sptpro_taxonomy_terms,
								'operator' => $sptpro_taxonomy_operator,
							);
						}
						$post_query = new WP_Query( $args );
						$posts      = $post_query->posts;
						foreach ( $posts as $key => $sptpro_tab ) {
							$sptpro_tab_priority++;
							$tabs[ 'sptpro_tab_' . $sptpro_tab_priority . $key ] = array(
								'title'    => $sptpro_tab->post_title,
								'priority' => $sptpro_tab_priority,
								'callback' => array( $this, 'sptpro_product_tabs_panel_content' ),
								'content'  => $sptpro_tab->post_content,
							);
						}
					}
				}
			}
		}
		return $tabs;
	}

	/**
	 * WooCommerce Tab Content.
	 *
	 * @param array $key tab key.
	 * @param array $tab woo tab content.
	 * @return void
	 */
	public function sptpro_product_tabs_panel_content( $key, $tab ) {
		$content = '';

		$sptpro_the_content_filter = apply_filters( 'sptpro_the_content_filter', true );

		if ( $sptpro_the_content_filter ) {
			$content = apply_filters( 'the_content', $tab['content'] );
		} else {
			$content = apply_filters( 'sptpro_woo_tab_content', $tab['content'] );
		}

		$tab_title_html = '<h2 class="sptpro-woo-tab-title sptpro-woo-tab-title-' . urldecode( sanitize_title( $tab['title'] ) ) . '">' . $tab['title'] . '</h2>';
		echo apply_filters( 'sptpro_repeatable_product_tabs_heading', $tab_title_html, $tab );
		echo apply_filters( 'sptpro_repeatable_product_tabs_content', $content, $tab );
	}

}
