<?php
/**
 * Define the shortcode functionality
 *
 * Loads and defines the shortcode for this plugin
 * so that it is ready for shortcode base view system.
 *
 * @link       https://shapedplugin.com/
 * @since      2.0.0
 *
 * @package    WP_Tabs_Pro
 * @subpackage WP_Tabs_Pro/includes
 */

/**
 * Define class for the shortcode functionality.
 */
class WP_Tabs_Pro_Shortcode {
	/**
	 * The ID of this plugin.
	 *
	 * @since    2.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    2.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    2.0.0
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Full html show.
	 *
	 * @param array $post_id Shortcode ID.
	 * @param array $sptpro_data_upload get all layout options.
	 * @param array $sptpro_shortcode_options get all meta options.
	 * @param array $main_section_title shows section title.
	 */
	public static function sp_tab_html_show( $post_id, $sptpro_data_upload, $sptpro_shortcode_options, $main_section_title ) {
		$sptpro_tab_type = isset( $sptpro_data_upload['sptpro_tab_type'] ) ? $sptpro_data_upload['sptpro_tab_type'] : 'content-tabs';

		$sptpro_data_src = isset( $sptpro_data_upload['sptpro_content_source'] ) ? $sptpro_data_upload['sptpro_content_source'] : '';

		$sptpro_data_src_sub = $sptpro_data_src ? wp_list_pluck( $sptpro_data_src, 'tabs_content_subtitle' ) : '';
		$sptpro_sub_span     = false;
		if ( ! empty( $sptpro_data_src_sub ) && ! array_filter( $sptpro_data_src_sub ) ) {
			$sptpro_sub_span = true;
		}

		$sptpro_tabs_layout             = isset( $sptpro_shortcode_options['sptpro_tabs_layout'] ) ? $sptpro_shortcode_options['sptpro_tabs_layout'] : '';
		$sptpro_tabs_carousel_alignment = isset( $sptpro_shortcode_options['sptpro_tabs_carousel_alignment'] ) ? $sptpro_shortcode_options['sptpro_tabs_carousel_alignment'] : '';
		$sptpro_tabs_vertical_position  = isset( $sptpro_shortcode_options['sptpro_tabs_vertical_position'] ) ? $sptpro_shortcode_options['sptpro_tabs_vertical_position'] : '';

		$sptpro_tabs_vertical_position = '';
		if ( 'vertical' === $sptpro_tabs_layout || 'carousel-vertical-left' === $sptpro_tabs_carousel_alignment ) {
			$sptpro_tabs_vertical_position = 'sp-tab__default-vertical-left';
		} elseif ( 'vertical-right' === $sptpro_tabs_layout || 'carousel-vertical-right' === $sptpro_tabs_carousel_alignment ) {
			$sptpro_tabs_vertical_position = 'sp-tab__default-vertical-right';
		}
		$sptpro_tabs_vertical_alignment = isset( $sptpro_shortcode_options['sptpro_tabs_vertical_alignment'] ) ? $sptpro_shortcode_options['sptpro_tabs_vertical_alignment'] : '';
		$sptpro_preloader               = isset( $sptpro_shortcode_options['sptpro_preloader'] ) ? $sptpro_shortcode_options['sptpro_preloader'] : false;

		$sptpro_tabs_position_bottom = '';
		if ( 'horizontal-bottom' === $sptpro_tabs_layout || 'carousel-horizontal-bottom' === $sptpro_tabs_carousel_alignment ) {
			$sptpro_tabs_position_bottom = ' sp-tab__horizontal-bottom';
		}

		$sptpro_tabs_horizontal_alignment = isset( $sptpro_shortcode_options['sptpro_tabs_horizontal_alignment'] ) ? $sptpro_shortcode_options['sptpro_tabs_horizontal_alignment'] : '';

		$sptpro_tabs_activator_event = isset( $sptpro_shortcode_options['sptpro_tabs_activator_event'] ) ? $sptpro_shortcode_options['sptpro_tabs_activator_event'] : '';
		$sptpro_autoplay_time        = isset( $sptpro_shortcode_options['sptpro_autoplay_time'] ) ? $sptpro_shortcode_options['sptpro_autoplay_time'] : '';
		$sptpro_pause_on_hover       = isset( $sptpro_shortcode_options['sptpro_pause_on_hover'] ) ? $sptpro_shortcode_options['sptpro_pause_on_hover'] : '';
		$sptpro_tab_opened           = isset( $sptpro_shortcode_options['sptpro_tab_opened'] ) ? $sptpro_shortcode_options['sptpro_tab_opened'] : '';
		$sptpro_tabs_icon            = isset( $sptpro_shortcode_options['sptpro_tabs_icon'] ) ? $sptpro_shortcode_options['sptpro_tabs_icon'] : false;
		$sptpro_strip_html_tags      = isset( $sptpro_shortcode_options['sptpro_strip_html_tags'] ) ? $sptpro_shortcode_options['sptpro_strip_html_tags'] : false;

		$sptpro_tab_icon_position          = isset( $sptpro_shortcode_options['sptpro_tab_icon_position'] ) ? $sptpro_shortcode_options['sptpro_tab_icon_position'] : '';
		$sptpro_tab_icon_position_vertical = isset( $sptpro_shortcode_options['sptpro_tab_icon_position_vertical'] ) ? $sptpro_shortcode_options['sptpro_tab_icon_position_vertical'] : '';
		$sptpro_item_title                 = isset( $sptpro_shortcode_options['sptpro_item_title'] ) ? $sptpro_shortcode_options['sptpro_item_title'] : true;

		$sptpro_active_tab_style_horizontal = isset( $sptpro_shortcode_options['sptpro_active_tab_style_horizontal'] ) ? $sptpro_shortcode_options['sptpro_active_tab_style_horizontal'] : 'horizontal-active-tab-normal';
		$sptpro_active_tab_style_vertical   = isset( $sptpro_shortcode_options['sptpro_active_tab_style_vertical'] ) ? $sptpro_shortcode_options['sptpro_active_tab_style_vertical'] : 'vertical-active-tab-normal';

		$sptpro_active_top_line = '';

		$is_top_border_tab_for_carousel = 'tabs-carousel' === $sptpro_tabs_layout && ( ( ( 'carousel-horizontal-top' === $sptpro_tabs_carousel_alignment || 'carousel-horizontal-bottom' === $sptpro_tabs_carousel_alignment ) && 'horizontal-active-tab-normal' !== $sptpro_active_tab_style_horizontal ) || ( ( 'carousel-vertical-left' === $sptpro_tabs_carousel_alignment || 'carousel-vertical-right' === $sptpro_tabs_carousel_alignment ) && 'vertical-active-tab-normal' !== $sptpro_active_tab_style_vertical ) );

		if ( ( ( 'horizontal' === $sptpro_tabs_layout || 'horizontal-bottom' === $sptpro_tabs_layout ) && 'horizontal-active-tab-normal' !== $sptpro_active_tab_style_horizontal ) || ( ( 'vertical' === $sptpro_tabs_layout || 'vertical-right' === $sptpro_tabs_layout ) && 'vertical-active-tab-normal' !== $sptpro_active_tab_style_vertical ) || $is_top_border_tab_for_carousel ) {
			$sptpro_active_top_line = ' sp-tab__top-border-active';
		}

		$sptpro_fixed_height = isset( $sptpro_shortcode_options['sptpro_fixed_height'] ) ? $sptpro_shortcode_options['sptpro_fixed_height'] : 'auto';

		$sptpro_tabs_on_small_screen = isset( $sptpro_shortcode_options['sptpro_tabs_on_small_screen'] ) ? $sptpro_shortcode_options['sptpro_tabs_on_small_screen'] : '';
		$small_screen                = isset( $sptpro_shortcode_options['sptpro_set_small_screen'] ) && is_array( $sptpro_shortcode_options['sptpro_set_small_screen'] ) ? $sptpro_shortcode_options['sptpro_set_small_screen']['all'] : '480';

		$sptpro_section_title     = isset( $sptpro_shortcode_options['sptpro_section_title'] ) ? $sptpro_shortcode_options['sptpro_section_title'] : false;
		$sptpro_title_heading_tag = isset( $sptpro_shortcode_options['sptpro_title_heading_tag'] ) ? $sptpro_shortcode_options['sptpro_title_heading_tag'] : 'h4';

		// Tabs Carousel Settings.
		$tabs_column        = isset( $sptpro_shortcode_options['sptpro_slides_to_show'] ) ? $sptpro_shortcode_options['sptpro_slides_to_show'] : '';
		$sptpro_tabs_column = ! empty( $tabs_column['lg_desktop'] ) ? $tabs_column['lg_desktop'] : '5';
		if ( 'content-tabs' === $sptpro_tab_type ) {
			$sptpro_data_total_items = is_array( $sptpro_data_src ) ? count( $sptpro_data_src ) : 0;
		} else {
			$sptpro_data_total_items = ! empty( $sptpro_data_upload['number_of_total_posts'] ) ? $sptpro_data_upload['number_of_total_posts'] : 6;
		}
		// If no of columns is greater than no of existing items then, override no. of columns to no. of existing items.
		if ( $sptpro_tabs_column > $sptpro_data_total_items ) {
			$sptpro_tabs_column = $sptpro_data_total_items;
		}
		$column_desktop          = ! empty( $tabs_column['desktop'] ) ? $tabs_column['desktop'] : '4';
		$column_laptop           = ! empty( $tabs_column['laptop'] ) ? $tabs_column['laptop'] : '3';
		$column_tablet           = ! empty( $tabs_column['tablet'] ) ? $tabs_column['tablet'] : '2';
		$column_mobile           = ! empty( $tabs_column['mobile'] ) ? $tabs_column['mobile'] : '1';
		$sptpro_variable_width   = ( isset( $sptpro_shortcode_options['sptpro_tabs_variable_width'] ) && $sptpro_shortcode_options['sptpro_tabs_variable_width'] ) ? 'true' : 'false';
		$sptpro_scroll_tabs_loop = isset( $sptpro_shortcode_options['sptpro_tabs_loop'] ) && $sptpro_shortcode_options['sptpro_tabs_loop'] ? 'true' : 'false';

		$tabs_scrollable_options = 'data-slick=\'{"slidesToShow":' . esc_attr( $sptpro_tabs_column ) . ', "infinite":' . esc_attr( $sptpro_scroll_tabs_loop ) . ', "responsive": [{"breakpoint":1280,"settings": { "slidesToShow":' . esc_attr( $column_desktop ) . '} },{"breakpoint":980,"settings": { "slidesToShow":' . esc_attr( $column_laptop ) . '} },{"breakpoint":736,"settings": { "slidesToShow":' . esc_attr( $column_tablet ) . '} },{"breakpoint":481,"settings": { "slidesToShow":' . esc_attr( $column_mobile ) . '} }]}\'';

		// Animation.
		$sptpro_tabs_animation      = isset( $sptpro_shortcode_options['sptpro_tabs_animation'] ) ? $sptpro_shortcode_options['sptpro_tabs_animation'] : false;
		$sptpro_tabs_animation_type = isset( $sptpro_shortcode_options['sptpro_tabs_animation_type'] ) ? $sptpro_shortcode_options['sptpro_tabs_animation_type'] : '';
		$sptpro_animation_time      = isset( $sptpro_shortcode_options['sptpro_animation_time'] ) ? $sptpro_shortcode_options['sptpro_animation_time'] : '';
		$sptpro_hush_url            = isset( $sptpro_shortcode_options['sptpro_hush_url'] ) ? $sptpro_shortcode_options['sptpro_hush_url'] : true;

		$allow_meta_tag = array(
			'div'  => array(
				'class' => array(),
			),
			'a'    => array(
				'href'  => array(),
				'title' => array(),
			),
			'span' => array(
				'class' => array(),
			),
			'img'  => array(
				'src'    => array(),
				'class'  => array(),
				'alt'    => array(),
				'width'  => array(),
				'height' => array(),
			),
		);

		wp_enqueue_script( 'sptpro-tab' );
		if ( 'custom' === $sptpro_fixed_height ) {
			wp_enqueue_script( 'sptpro-smooth-scrollbar' );
		}
		$sptpro_data_vertical_align_fill = false;
		if ( 'vertical' === $sptpro_tabs_layout && 'tab-vertical-alignment-top' !== $sptpro_tabs_vertical_alignment ) {
			$sptpro_data_vertical_align_fill = true;
			wp_enqueue_script( 'sptpro-match-height' );
		}
		wp_enqueue_script( 'sptpro-script' );
		// Tabs Scrollable JS.
		if ( 'tabs-carousel' === $sptpro_tabs_layout ) {
			wp_enqueue_script( 'sptpro-tab-carousel-script' );
		}

		include WP_TABS_PRO_PATH . 'public/partials/section-title.php';
		// Trigger resize event on clicking of tab title when this hook return true.
		$tabs_resize_event = apply_filters( 'sp_tabs_trigger_resize_event', false );
		// This hook to enable scroll to top on clicking of tab accordion in mobile accordion view.
		$animate_scroll_top = apply_filters( 'sp_tabs_animate_panel_scroll_top', true, $post_id );
		$tabs_resize_event  = $tabs_resize_event ? 'true' : 'false';

		$number_of_total_tab_items = is_array( $sptpro_data_src ) ? count( $sptpro_data_src ) : 0;

		$sptpro_tabs_carousel = 'tabs-carousel' === $sptpro_tabs_layout ? ' sp-tab__nav-tabs-scrollable' : '';

		if ( ( 'tabs-carousel' === $sptpro_tabs_layout ) && ( 'carousel-vertical-left' === $sptpro_tabs_carousel_alignment || 'carousel-vertical-right' === $sptpro_tabs_carousel_alignment ) ) {
			$sptpro_tabs_layout = 'vertical';
		}

		switch ( $sptpro_tab_type ) {
			case 'content-tabs':
				switch ( $sptpro_tabs_on_small_screen ) {
					case 'full_widht':
						include WP_TABS_PRO_PATH . 'public/partials/tabs-default.php';
						break;
					case 'accordion_mode':
						include WP_TABS_PRO_PATH . 'public/partials/tabs-accordion-default.php';
						break;
				}
				break;
			case 'post-tabs':
				switch ( $sptpro_tabs_on_small_screen ) {
					case 'full_widht':
						include WP_TABS_PRO_PATH . 'public/partials/tabs-post.php';
						break;
					case 'accordion_mode':
						include WP_TABS_PRO_PATH . 'public/partials/tabs-accordion-post.php';
						break;
				}
				break;
		}
	}

	/**
	 * ShortCode of the Plugin.
	 *
	 * @since 2.0.0
	 * @param array $attributes The Attribute of the ShortCode.
	 * @param null  $content Param.
	 */
	public function sptpro_shortcode_execute( $attributes, $content = null ) {

		$manage_license     = new WP_Tabs_Pro_License( WP_TABS_PRO_FILE, WP_TABS_PRO_VERSION, 'ShapedPlugin', WP_TABS_PRO_STORE_URL, WP_TABS_PRO_ITEM_ID, WP_TABS_PRO_ITEM_SLUG );
		$license_key_status = $manage_license->get_license_status();
		$license_status     = ( is_object( $license_key_status ) && $license_key_status ? $license_key_status->license : '' );
		$if_license_status  = array( 'valid', 'expired' );
		if ( ! in_array( $license_status, $if_license_status ) ) {
			$activation_notice = '';
			if ( current_user_can( 'manage_options' ) ) {
				$activation_notice = sprintf(
					'<div class="wp-tabs-pro-license-notice" style="background: #ffebee;color: #444;padding: 18px 16px;border: 1px solid #d0919f;border-radius: 4px;font-size: 18px;line-height: 28px;">Please <strong><a href="%1$s">activate</a></strong> the license key to get the output of the <strong>WP Tabs Pro</strong> plugin.</div>',
					esc_url( admin_url( 'edit.php?post_type=sp_wp_tabs&page=tabs_settings#tab=1' ) )
				);
			}
			return $activation_notice;
		}

		// Check the shortcode existence, post type and post status.
		if ( empty( $attributes['id'] ) || 'sp_wp_tabs' !== get_post_type( $attributes['id'] ) || 'trash' === get_post_status( $attributes['id'] ) ) {
			return;
		}
		$post_id = (int) esc_attr( $attributes['id'] );

		$sptpro_data_upload       = get_post_meta( $post_id, 'sp_tab_source_options', true );
		$sptpro_shortcode_options = get_post_meta( $post_id, 'sp_tab_shortcode_options', true );
		$main_section_title       = get_the_title( $post_id );
		$sptpro_tabs_layout       = isset( $sptpro_shortcode_options['sptpro_tabs_layout'] ) ? $sptpro_shortcode_options['sptpro_tabs_layout'] : '';
		if ( ! is_array( $sptpro_data_upload ) ) {
			return;
		}
		ob_start();
		// Stylesheet loading problem solving here. Shortcode id to push page id option for getting how many shortcode in the page.
		$current_page_id    = get_queried_object_id();
		$option_key         = 'sp_tabs_page_id' . $current_page_id;
		$found_generator_id = get_option( $option_key );
		if ( is_multisite() ) {
			$option_key         = 'sp_tabs_page_id' . get_current_blog_id() . $current_page_id;
			$found_generator_id = get_site_option( $option_key );
		}
		// This shortcode id not in page id option. Enqueue stylesheets in shortcode.
		if ( ! is_array( $found_generator_id ) || ! $found_generator_id || ! in_array( $post_id, $found_generator_id ) ) {
			wp_enqueue_style( 'sptpro-font-awesome' );
			wp_enqueue_style( 'sptpro-animate-css' );
			if ( 'tabs-carousel' === $sptpro_tabs_layout ) {
				wp_enqueue_style( 'sptpro-tab-carousel-style' );
				wp_enqueue_style( 'sptpro-tab-carousel-theme-style' );
			}
			wp_enqueue_style( 'sptpro-style' );
			$sptpro_typography    = array();
			$sptpro_dynamic_style = '';
			include WP_TABS_PRO_PATH . 'public/dynamic_style.php';

			// Custom CSS loads.
			$settings              = get_option( 'sp-tab__settings' );
			$custom_style          = isset( $settings['sptpro_custom_css'] ) ? trim( html_entity_decode( $settings['sptpro_custom_css'] ) ) : '';
			$sptpro_dynamic_style .= $custom_style;
			$dynamic_style         = WP_Tabs_Pro_Public::minify_output( $sptpro_dynamic_style );
			echo '<style id="sp_tabs_dynamic_css' . esc_attr( $post_id ) . '">' . $dynamic_style . '</style>'; // phpcs:ignore

			/**
			* Google font link enqueue
			*/
			if ( $sptpro_dequeue_google_font ) {
				$enqueue_fonts = WP_Tabs_Pro_Public::load_google_fonts( $sptpro_typography );
				if ( ! empty( $enqueue_fonts ) ) {
					wp_enqueue_style( 'sptpro-google-fonts' . $post_id, esc_url( add_query_arg( 'family', rawurlencode( implode( '|', $enqueue_fonts ) ), '//fonts.googleapis.com/css' ) ), array(), '2.0.0' );
				}
			}
		}

		if ( $found_generator_id ) {
			$found_generator_id = is_array( $found_generator_id ) ? $found_generator_id : array( $found_generator_id );
			if ( ! in_array( $post_id, $found_generator_id ) || empty( $found_generator_id ) ) {
				// If not found the shortcode id in the page options.
				array_push( $found_generator_id, $post_id );
				if ( is_multisite() ) {
					update_site_option( $option_key, $found_generator_id );
				} else {
					update_option( $option_key, $found_generator_id );
				}
			}
		} else {
			// If option not set in current page add option.
			if ( $current_page_id ) {
				if ( is_multisite() ) {
					add_site_option( $option_key, array( $post_id ) );
				} else {
					add_option( $option_key, array( $post_id ) );
				}
			}
		}

		self::sp_tab_html_show( $post_id, $sptpro_data_upload, $sptpro_shortcode_options, $main_section_title );
		return ob_get_clean();
	}

}
