<?php
/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://shapedplugin.com/
 * @since      1.0.0
 *
 * @package    WP_Tabs_Pro
 * @subpackage WP_Tabs_Pro/public/partials
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

wp_enqueue_style( 'sptpro-accordion-style' );
wp_enqueue_script( 'sptpro-collapse' );
$number_of_total_tab_items = is_array( $sptpro_data_src ) ? count( $sptpro_data_src ) : 0;

echo '<div id="sp-tabpro-wrapper_' . esc_attr( $post_id ) . '" class="sp-tab__lay-default sp-tab__default-accordion ' . esc_attr( $sptpro_tabs_vertical_position ) . esc_attr( $sptpro_tabs_position_bottom ) . esc_attr( $sptpro_active_top_line ) . ' tab-layout-' . esc_attr( $sptpro_tabs_layout ) . '" data-preloader="' . esc_attr( $sptpro_preloader ) . '" data-activemode="' . esc_attr( $sptpro_tabs_activator_event ) . '" data-autoplaytime="' . esc_attr( $sptpro_autoplay_time ) . '" data-pause_on_hover="' . esc_attr( $sptpro_pause_on_hover ) . '" data-tab_resize_event="' . esc_attr( $tabs_resize_event ) . '" data-valignfill="' . esc_attr( $sptpro_data_vertical_align_fill ) . '" data-animate_scroll_top="' . esc_attr( $animate_scroll_top ) . '" data-hush_url=' . esc_attr( $sptpro_hush_url ) . '>';
if ( $sptpro_preloader ) {
	echo '<div id="sp-tabpro-preloader-' . esc_attr( $post_id ) . '" class="sp-tab__preloader">
			<img src="' . esc_url( WP_TABS_PRO_URL ) . '/public/css/spinner.svg" alt="loader-icon"/>
		</div>';
}

echo '<ul class="sp-tab__nav sp-tab__nav-tabs ' . esc_attr( $sptpro_tabs_carousel ) . '" ' . $tabs_scrollable_options . ' data-screen-size="' . esc_attr( $small_screen ) . '" data-small-screen-type="' . esc_attr( $sptpro_tabs_on_small_screen ) . '" data-variable_width="' . esc_attr( $sptpro_variable_width ) . '" id="sp-tab__ul" role="tablist">'; // phpcs:ignore

if ( is_array( $sptpro_data_src ) || is_object( $sptpro_data_src ) ) {
	$sptpro_data_count = 1;
	foreach ( $sptpro_data_src as $key => $sptpro_data ) {
		$sptpro_active_class = $sptpro_tab_opened == $sptpro_data_count ? ' sp-tab__active' : '';
		$tabs_content_title  = ( $sptpro_item_title ) ? '<' . $sptpro_title_heading_tag . ' class="sp-tab__tab_title">' . $sptpro_data['tabs_content_title'] . '</' . $sptpro_title_heading_tag . '>' : '';

		$tabs_content_icon = isset( $sptpro_data['tabs_content_icon'] ) && is_string( $sptpro_data['tabs_content_icon'] ) ? $sptpro_data['tabs_content_icon'] : '';
		$tabs_custom_icon  = isset( $sptpro_data['tabs_custom_icon'] ) ? $sptpro_data['tabs_custom_icon'] : '';
		$sptpro_fa_fa      = '';
		if ( ! empty( $tabs_content_icon ) ) {
			$sptpro_fa_fa = ( $sptpro_tabs_icon && ! empty( $tabs_content_icon ) ) ? '<i class="fa ' . $tabs_content_icon . ' sp-tab-fa"> </i>' : '';
		} elseif ( ! empty( $tabs_custom_icon['url'] ) ) {
			$sptpro_fa_fa = ( $sptpro_tabs_icon ) ? '<img src="' . $tabs_custom_icon['url'] . '" class="tabs-custom-icon" alt="' . $tabs_custom_icon['alt'] . '"/>' : '';
		}

		$sptpro_tab_icon_position_swap = '<span class="tab_title_area">' . $sptpro_fa_fa . $tabs_content_title . '</span>';
		$is_horizontal_layout          = ( 'horizontal' === $sptpro_tabs_layout || 'horizontal-bottom' === $sptpro_tabs_layout ) && 'tab-icon-position-right' === $sptpro_tab_icon_position;

		$is_vertical_layout = ( 'vertical' === $sptpro_tabs_layout || 'vertical-right' === $sptpro_tabs_layout ) && 'vertical-tab-icon-position-right' === $sptpro_tab_icon_position_vertical;

		$is_tab_carousel = 'tabs-carousel' === $sptpro_tabs_layout && ( ( ( 'carousel-horizontal-top' === $sptpro_tabs_carousel_alignment || 'carousel-horizontal-bottom' === $sptpro_tabs_carousel_alignment ) && 'tab-icon-position-right' === $sptpro_tab_icon_position ) || ( ( 'carousel-vertical-left' === $sptpro_tabs_carousel_alignment || 'carousel-vertical-right' === $sptpro_tabs_carousel_alignment ) && 'vertical-tab-icon-position-right' === $sptpro_tab_icon_position_vertical ) );

		if ( $is_horizontal_layout || $is_vertical_layout || $is_tab_carousel ) {
			$sptpro_tab_icon_position_swap = '<span class="tab_title_area">' . $tabs_content_title . $sptpro_fa_fa . '</span>';
		}

		$tabs_content_subtitle = $sptpro_data['tabs_content_subtitle'] ? $sptpro_data['tabs_content_subtitle'] : '(no sub)';
		if ( 'tab-icon-position-top' === $sptpro_tab_icon_position ) {
			$tabs_content_sub_visible = $sptpro_data['tabs_content_subtitle'] ? 'visibility: visible !important;' : 'display: none;';
		} else {
			$tabs_content_sub_visible = $sptpro_data['tabs_content_subtitle'] ? 'visibility: visible !important;' : 'visibility: hidden;';
		}
		$tabs_inactive             = isset( $sptpro_data['tabs_inactive'] ) && $sptpro_data['tabs_inactive'] ? ' sp-tab__disabled' : '';
		$tabs_aria_controls_for_id = 'tab-' . $post_id . $sptpro_data_count;
		$name_url                  = preg_replace( '/\s+/', '-', sanitize_title( $sptpro_data['tabs_content_title'] ) );
		$tab_name_url              = apply_filters( 'sp_tabs_name_slug', false );
		$tabs_aria_controls_for_id = $tab_name_url ? strtolower( $name_url ) : $tabs_aria_controls_for_id;
		$tabs_linking              = isset( $sptpro_data['tabs_linking'] ) ? $sptpro_data['tabs_linking'] : false;
		$tabs_link_target          = isset( $sptpro_data['tabs_link_target'] ) ? $sptpro_data['tabs_link_target'] : '_blank';
		$tabs_content_url          = isset( $sptpro_data['tabs_content_url'] ) ? $sptpro_data['tabs_content_url'] : '';

		echo '<li class="sp-tab__nav-item" role="tab" >';

		if ( ! $sptpro_sub_span ) {

			if ( $tabs_linking ) {
				echo '<a class="sp-tab__nav-link" href="' . esc_url( $tabs_content_url ) . '" target="' . esc_attr( $tabs_link_target ) . '">' . wp_kses_post( $sptpro_tab_icon_position_swap ) . '<span class="sp-tab__tab_subtitle" style="' . esc_attr( $tabs_content_sub_visible ) . '">' . esc_html( $tabs_content_subtitle ) . '</span></a>';
			} else {
				echo '<label class="sp-tab__nav-link' . esc_attr( $sptpro_active_class ) . esc_attr( $tabs_inactive ) . '" data-sptoggle="tab" for="#' . esc_attr( $tabs_aria_controls_for_id ) . '" aria-selected="true" tabindex="0">' . wp_kses_post( $sptpro_tab_icon_position_swap ) . '<span class="sp-tab__tab_subtitle" style="' . esc_attr( $tabs_content_sub_visible ) . '">' . esc_html( $tabs_content_subtitle ) . '</span></label>';
			}
		} else {

			if ( $tabs_linking ) {
				echo '<a class="sp-tab__nav-link" href="' . esc_url( $tabs_content_url ) . '" target="' . esc_attr( $tabs_link_target ) . '">' . wp_kses_post( $sptpro_tab_icon_position_swap ) . '</a>';
			} else {
				echo '<label class="sp-tab__nav-link' . esc_attr( $sptpro_active_class ) . esc_attr( $tabs_inactive ) . '" data-sptoggle="tab" for="#' . esc_attr( $tabs_aria_controls_for_id ) . '" aria-selected="true" tabindex="0">' . wp_kses_post( $sptpro_tab_icon_position_swap ) . '</label>';
			}
		}

		echo '</li>';

		$sptpro_data_count++;
	}
}

echo '</ul>
<div class="sp-tab__tab-content" id="wpt-accordion-' . esc_attr( $post_id ) . '">';

if ( is_array( $sptpro_data_src ) || is_object( $sptpro_data_src ) ) {

	$sptpro_cont_count = 1;
	foreach ( $sptpro_data_src as $key => $sptpro_data ) {

		global $wp_embed;
		$sptpro_active_class = $sptpro_tab_opened == $sptpro_cont_count ? 'sp-tab__show sp-tab__active' : '';  // phpcs:ignore
		$sptpro_show_class   = $sptpro_tab_opened == $sptpro_cont_count ? 'sp-tab__show' : '';  // phpcs:ignore
		// Keep accordion all items folded in mobile if hook return true.
		if ( apply_filters( 'sptpro_keep_accordion_items_folded_in_mobile', false ) ) {
			$sptpro_show_class = '';
		}
		$tabs_pane_variable_id       = 'tab-' . $post_id . $sptpro_cont_count;
		$name_url                    = preg_replace( '/\s+/', '-', sanitize_title( $sptpro_data['tabs_content_title'] ) );
		$tab_name_url                = apply_filters( 'sp_tabs_name_slug', false );
		$tabs_pane_variable_id       = $tab_name_url ? strtolower( $name_url ) : $tabs_pane_variable_id;
		$tabs_pane_variable_controls = 'collapse-' . $post_id . $sptpro_cont_count;
		$tabs_pane_variable_heading  = 'heading-' . $post_id . $sptpro_cont_count;
		$tabs_linking                = isset( $sptpro_data['tabs_linking'] ) ? $sptpro_data['tabs_linking'] : false;
		$tabs_link_target            = isset( $sptpro_data['tabs_link_target'] ) ? $sptpro_data['tabs_link_target'] : '_blank';
		$tabs_content_url            = isset( $sptpro_data['tabs_content_url'] ) ? $sptpro_data['tabs_content_url'] : '';
		$tabs_content_title          = $sptpro_data['tabs_content_title'];
		$accordion_deep_link         = '<a class="sp-tab__link" href="' . esc_url( $tabs_content_url ) . '" target="' . $tabs_link_target . '"><div class="sp-tab__card-header" role="sptab" id="' . $tabs_pane_variable_heading . '">' . $tabs_content_title . '</div></a>';
		$aria_expanded               = $sptpro_show_class ? 'true' : 'false';
		// Accordion title.
		$accordion_header     = $tabs_linking ? $accordion_deep_link : '<label data-sptoggle="collapse" for="#' . $tabs_pane_variable_controls . '" aria-expanded="' . $aria_expanded . '" aria-controls="' . $tabs_pane_variable_controls . '"><div class="sp-tab__card-header" role="sptab" id="' . $tabs_pane_variable_heading . '">' . $tabs_content_title . '</div></label>';
		$sptpro_content       = apply_filters( 'sp_wp_tabs_content', $sptpro_data['tabs_content_description'] );
		$sptpro_content_embed = str_replace( ']]>', ']]&gt;', $sptpro_content );
		if ( apply_filters( 'sp_wp_tabs_wpautop_remove', true ) ) {
			$sptpro_content_embed = wpautop( trim( $sptpro_content_embed ) );
		}
		$tabs_content_description = do_shortcode( shortcode_unautop( $wp_embed->autoembed( $sptpro_content_embed ) ) );
		$tabs_content_description = $sptpro_strip_html_tags ? wp_strip_all_tags( $tabs_content_description ) : $tabs_content_description;
		$animation_name           = $sptpro_tabs_animation ? 'animated ' . $sptpro_tabs_animation_type : '';

		echo '<div id="' . esc_attr( $tabs_pane_variable_id ) . '" class="sp-tab__card sp-tab__tab-pane ' . esc_attr( $sptpro_active_class ) . '" role="tabpanel" aria-hidden="false" aria-labelledby="' . esc_attr( $tabs_pane_variable_heading ) . '">' . wp_kses_post( $accordion_header ) . '
			
			<div id="' . esc_attr( $tabs_pane_variable_controls ) . '" class="sp-tab__collapse ' . esc_attr( $sptpro_show_class ) . '" data-parent="#wpt-accordion-' . esc_attr( $post_id ) . '" role="tabpanel" aria-labelledby="' . esc_attr( $tabs_pane_variable_heading ) . '">
				<div class="sp-tab__card-body">
					<div class="' . esc_attr( $animation_name ) . '">
					' . $tabs_content_description . '</div>
				</div>
			</div>
		</div>';

		$sptpro_cont_count++;
	}
}

echo '</div>
</div>';
