<?php
/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://shapedplugin.com/
 * @since      1.0.0
 *
 * @package    WP_Tabs_Pro
 * @subpackage WP_Tabs_Pro/public/partials
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

$sptpro_post_data_src      = $sptpro_data_upload;
$sptpro_post_type          = ( isset( $sptpro_post_data_src['sptpro_post_type'] ) ? $sptpro_post_data_src['sptpro_post_type'] : 'post' );
$sptpro_display_posts_from = ( isset( $sptpro_post_data_src['sptpro_display_posts_from'] ) ? $sptpro_post_data_src['sptpro_display_posts_from'] : '' );
$sptpro_post_taxonomy      = ( isset( $sptpro_post_data_src['sptpro_post_taxonomy'] ) ? $sptpro_post_data_src['sptpro_post_taxonomy'] : '' );
$sptpro_taxonomy_terms     = ( isset( $sptpro_post_data_src['sptpro_taxonomy_terms'] ) ? $sptpro_post_data_src['sptpro_taxonomy_terms'] : '' );
$sptpro_taxonomy_operator  = ( isset( $sptpro_post_data_src['taxonomy_operator'] ) ? $sptpro_post_data_src['taxonomy_operator'] : '' );
$sptpro_specific_posts     = ( isset( $sptpro_post_data_src['sptpro_specific_posts'] ) ? $sptpro_post_data_src['sptpro_specific_posts'] : '' );
$number_of_total_posts     = ( isset( $sptpro_post_data_src['number_of_total_posts'] ) ? $sptpro_post_data_src['number_of_total_posts'] : '' );
$post_order_by             = ( isset( $sptpro_post_data_src['post_order_by'] ) ? $sptpro_post_data_src['post_order_by'] : 'date' );
$post_order                = ( isset( $sptpro_post_data_src['post_order'] ) ? $sptpro_post_data_src['post_order'] : 'DESC' );

if ( empty( $sptpro_post_type ) ) {
	return;
}
$args = array(
	'post_type'           => $sptpro_post_type,
	'post_status'         => 'publish',
	'ignore_sticky_posts' => 1,
	'post__in'            => $sptpro_specific_posts,
	'posts_per_page'      => $number_of_total_posts,
	'orderby'             => $post_order_by,
	'order'               => $post_order,
);
if ( 'taxonomy' === $sptpro_display_posts_from && ! empty( $sptpro_post_taxonomy ) && ! empty( $sptpro_taxonomy_terms ) ) {
	$args['tax_query'][] = array(
		'taxonomy' => $sptpro_post_taxonomy,
		'field'    => 'term_id',
		'terms'    => $sptpro_taxonomy_terms,
		'operator' => $sptpro_taxonomy_operator,
	);
}
$post_query = new WP_Query( $args );
wp_enqueue_style( 'sptpro-accordion-style' );
wp_enqueue_script( 'sptpro-collapse' );

echo '<div id="sp-tabpro-wrapper_' . esc_attr( $post_id ) . '" class="sp-tab__lay-default sp-tab__default-accordion ' . esc_attr( $sptpro_tabs_vertical_position ) . esc_attr( $sptpro_tabs_position_bottom ) . esc_attr( $sptpro_active_top_line ) . ' tab-layout-' . esc_attr( $sptpro_tabs_layout ) . '" data-preloader="' . esc_attr( $sptpro_preloader ) . '" data-activemode="' . esc_attr( $sptpro_tabs_activator_event ) . '" data-autoplaytime="' . esc_attr( $sptpro_autoplay_time ) . '" data-pause_on_hover="' . esc_attr( $sptpro_pause_on_hover ) . '"   data-valignfill="' . esc_attr( $sptpro_data_vertical_align_fill ) . '" data-tab_resize_event="' . esc_attr( $tabs_resize_event ) . '" data-animate_scroll_top="' . esc_attr( $animate_scroll_top ) . '" data-hush_url=' . esc_attr( $sptpro_hush_url ) . '>';
if ( $sptpro_preloader ) {
	echo '<div id="sp-tabpro-preloader-' . esc_attr( $post_id ) . '" class="sp-tab__preloader">
			<img src="' . esc_url( WP_TABS_PRO_URL ) . '/public/css/spinner.svg" alt="loader-icon"/>
		</div>';
}
echo '<ul class="sp-tab__nav sp-tab__nav-tabs ' . esc_attr( $sptpro_tabs_carousel ) . '" ' . $tabs_scrollable_options . ' data-screen-size="' . esc_attr( $small_screen ) . '" data-small-screen-type="' . esc_attr( $sptpro_tabs_on_small_screen ) . '" data-variable_width="' . esc_attr( $sptpro_variable_width ) . '" id="sp-tab__ul" role="tablist">'; // phpcs:ignore

if ( is_array( $sptpro_post_data_src ) || is_object( $sptpro_post_data_src ) ) {
	$sptpro_data_count = 1;

	// First loop.
	if ( $post_query->have_posts() ) {
		while ( $post_query->have_posts() ) {
				$post_query->the_post();
			$sptpro_active_class       = $sptpro_tab_opened == $sptpro_data_count ? 'sp-tab__active' : ''; // phpcs:ignore
			$tabs_content_title        = ( $sptpro_item_title ) ? '<' . $sptpro_title_heading_tag . ' class="sp-tab__tab_title">' . get_the_title( get_the_ID() ) . '</' . $sptpro_title_heading_tag . '>' : '';
			$tabs_aria_controls_for_id = 'tab-' . $post_id . $sptpro_data_count;
			$name_url                  = preg_replace( '/\s+/', '-', sanitize_title( get_the_title( get_the_ID() ) ) );
			$tab_name_url              = apply_filters( 'sp_tabs_name_slug', false );
			$tabs_aria_controls_for_id = $tab_name_url ? strtolower( $name_url ) : $tabs_aria_controls_for_id;
			include WP_TABS_PRO_PATH . '/public/partials/post-meta.php';
			echo '<li class="sp-tab__nav-item"  role="tab">';
			echo '<label class="sp-tab__nav-link ' . esc_attr( $sptpro_active_class ) . '" data-sptoggle="tab" for="#' . esc_attr( $tabs_aria_controls_for_id ) . '" aria-selected="true" tabindex="0">' . wp_kses_post( $tabs_content_title ) . $post_meta_after_title . '</label>'; // phpcs:ignore
			echo '</li>';

			$sptpro_data_count++;
		}
	}

	echo '</ul>
	<div class="sp-tab__tab-content"  id="wpt-accordion-' . esc_attr( $post_id ) . '">';

	// Second loop.
	$sptpro_cont_count = 1;
	if ( $post_query->have_posts() ) {
		while ( $post_query->have_posts() ) {
				$post_query->the_post();
			$sptpro_active_class = $sptpro_tab_opened == $sptpro_cont_count ? 'sp-tab__show sp-tab__active' : ''; // phpcs:ignore
			$sptpro_show_class   = $sptpro_tab_opened == $sptpro_cont_count ? 'sp-tab__show' : ''; // phpcs:ignore
			// Keep accordion all items folded in mobile if hook return true.
			if ( apply_filters( 'sptpro_keep_accordion_items_folded_in_mobile', false ) ) {
				$sptpro_show_class = '';
			}

			$tabs_pane_variable_id       = 'tab-' . $post_id . $sptpro_cont_count;
			$name_url                    = preg_replace( '/\s+/', '-', sanitize_title( get_the_title( get_the_ID() ) ) );
			$tab_name_url                = apply_filters( 'sp_tabs_name_slug', false );
			$tabs_pane_variable_id       = $tab_name_url ? strtolower( $name_url ) : $tabs_pane_variable_id;
			$tabs_pane_variable_controls = 'collapse-' . $post_id . $sptpro_cont_count;
			$tabs_pane_variable_heading  = 'heading-' . $post_id . $sptpro_cont_count;
			global $wp_embed;
			$sptpro_content = do_shortcode( $wp_embed->autoembed( get_the_content() ) );
			if ( function_exists( 'do_blocks' ) ) {
				$sptpro_content = do_blocks( $sptpro_content );
			}
			$tabs_content_title  = get_the_title( get_the_ID() );
			$sptpro_content_ptag = wpautop( trim( preg_replace( '/<!--(.|s)*?-->/', '', $sptpro_content ) ) );
			$animation_name      = $sptpro_tabs_animation ? 'animated ' . $sptpro_tabs_animation_type : '';
			$aria_expanded       = $sptpro_show_class ? 'true' : 'false';
			include WP_TABS_PRO_PATH . '/public/partials/feature-image.php';
			include WP_TABS_PRO_PATH . '/public/partials/post-meta.php';

			echo '<div id="' . esc_attr( $tabs_pane_variable_id ) . '" class="sp-tab__card sp-tab__tab-pane ' . esc_attr( $sptpro_active_class ) . '" aria-labelledby="' . esc_attr( $tabs_pane_variable_heading ) . '" role="tabpanel">
			<label data-sptoggle="collapse" for="#' . esc_attr( $tabs_pane_variable_controls ) . '" aria-expanded="' . esc_attr( $aria_expanded ) . '" aria-controls="' . esc_attr( $tabs_pane_variable_controls ) . '">
				<div class="sp-tab__card-header"  id="' . esc_attr( $tabs_pane_variable_heading ) . '">' . wp_kses_post( $tabs_content_title ) . $post_meta_after_title . '</div>
			</label>

			<div id="' . esc_attr( $tabs_pane_variable_controls ) . '" class="sp-tab__collapse ' . esc_attr( $sptpro_show_class ) . '" data-parent="#wpt-accordion-' . esc_attr( $post_id ) . '" aria-labelledby="' . esc_attr( $tabs_pane_variable_heading ) . '">
				<div class="sp-tab__card-body">
					<div class="sp-tabs-accordion-body ' . esc_attr( $animation_name ) . '">' . wp_kses( $post_thumb, $allow_meta_tag ) . '<div class="sp-tab__tab-content">' . $post_meta_before_descriptions . $sptpro_content_ptag . '</div></div>'; // phpcs:ignore
					// These variables are escaped where these are defined.
			echo '</div>
			</div>
		</div>';

			$sptpro_cont_count++;
		}
		wp_reset_postdata();
	}
}

echo '</div>
</div>';
