<?php
/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://shapedplugin.com/
 * @since      1.0.0
 *
 * @package    WP_Tabs_Pro
 * @subpackage WP_Tabs_Pro/public/partials
 */

if ( ! defined( 'WPINC' ) ) {
	die;
}

$sptpro_post_data_src      = $sptpro_data_upload;
$sptpro_post_type          = ( isset( $sptpro_post_data_src['sptpro_post_type'] ) ? $sptpro_post_data_src['sptpro_post_type'] : 'post' );
$sptpro_display_posts_from = ( isset( $sptpro_post_data_src['sptpro_display_posts_from'] ) ? $sptpro_post_data_src['sptpro_display_posts_from'] : '' );
$sptpro_post_taxonomy      = ( isset( $sptpro_post_data_src['sptpro_post_taxonomy'] ) ? $sptpro_post_data_src['sptpro_post_taxonomy'] : '' );
$sptpro_taxonomy_terms     = ( isset( $sptpro_post_data_src['sptpro_taxonomy_terms'] ) ? $sptpro_post_data_src['sptpro_taxonomy_terms'] : '' );
$sptpro_taxonomy_operator  = ( isset( $sptpro_post_data_src['taxonomy_operator'] ) ? $sptpro_post_data_src['taxonomy_operator'] : '' );
$sptpro_specific_posts     = ( isset( $sptpro_post_data_src['sptpro_specific_posts'] ) ? $sptpro_post_data_src['sptpro_specific_posts'] : '' );
$number_of_total_posts     = ( isset( $sptpro_post_data_src['number_of_total_posts'] ) ? $sptpro_post_data_src['number_of_total_posts'] : '' );
$post_order_by             = ( isset( $sptpro_post_data_src['post_order_by'] ) ? $sptpro_post_data_src['post_order_by'] : 'date' );
$post_order                = ( isset( $sptpro_post_data_src['post_order'] ) ? $sptpro_post_data_src['post_order'] : 'DESC' );

if ( empty( $sptpro_post_type ) ) {
	return;
}
$args = array(
	'post_type'           => $sptpro_post_type,
	'post_status'         => 'publish',
	'ignore_sticky_posts' => 1,
	'posts_per_page'      => $number_of_total_posts,
	'orderby'             => $post_order_by,
	'order'               => $post_order,
);
if ( 'specific_post' === $sptpro_display_posts_from ) {
	$sptpro_get_specific = array(
		'post__in'       => $sptpro_specific_posts,
		'posts_per_page' => -1,
	);
	$args                = array_merge( $args, $sptpro_get_specific );
}
if ( 'taxonomy' === $sptpro_display_posts_from && ! empty( $sptpro_post_taxonomy ) && ! empty( $sptpro_taxonomy_terms ) ) {
	$args['tax_query'][] = array(
		'taxonomy' => $sptpro_post_taxonomy,
		'field'    => 'term_id',
		'terms'    => $sptpro_taxonomy_terms,
		'operator' => $sptpro_taxonomy_operator,
	);
}
$post_query = new WP_Query( $args );

echo '<div id="sp-tabpro-wrapper_' . esc_attr( $post_id ) . '" class="sp-tab__lay-default ' . esc_attr( $sptpro_tabs_vertical_position ) . esc_attr( $sptpro_tabs_position_bottom ) . esc_attr( $sptpro_active_top_line ) . ' tab-layout-' . esc_attr( $sptpro_tabs_layout ) . '" data-preloader="' . esc_attr( $sptpro_preloader ) . '" data-activemode="' . esc_attr( $sptpro_tabs_activator_event ) . '" data-tab_resize_event="' . esc_attr( $tabs_resize_event ) . '"  data-autoplaytime="' . esc_attr( $sptpro_autoplay_time ) . '" data-pause_on_hover="' . esc_attr( $sptpro_pause_on_hover ) . '" data-valignfill="' . esc_attr( $sptpro_data_vertical_align_fill ) . '" data-animate_scroll_top="' . esc_attr( $animate_scroll_top ) . '" data-hush_url=' . esc_attr( $sptpro_hush_url ) . '>';
if ( $sptpro_preloader ) {
	echo '<div id="sp-tabpro-preloader-' . esc_attr( $post_id ) . '" class="sp-tab__preloader">
			<img src="' . esc_url( WP_TABS_PRO_URL ) . '/public/css/spinner.svg" alt="loader-icon"/>
		</div>';
}
echo '<ul class="sp-tab__nav sp-tab__nav-tabs ' . esc_attr( $sptpro_tabs_carousel ) . '" ' . $tabs_scrollable_options . ' data-screen-size="' . esc_attr( $small_screen ) . '" data-small-screen-type="' . esc_attr( $sptpro_tabs_on_small_screen ) . '" data-variable_width="' . esc_attr( $sptpro_variable_width ) . '" id="sp-tab__ul" role="tablist">'; // phpcs:ignore

if ( is_array( $sptpro_post_data_src ) ) {
	$sptpro_data_count = 1;

	// First loop.
	if ( $post_query->have_posts() ) {

		while ( $post_query->have_posts() ) {
			$post_query->the_post();
			$sptpro_active_class       = $sptpro_tab_opened == $sptpro_data_count ? 'sp-tab__active' : ''; // phpcs:ignore
			$tabs_content_title        = ( $sptpro_item_title ) ? '<' . $sptpro_title_heading_tag . ' class="sp-tab__tab_title">' . get_the_title( get_the_ID() ) . '</' . $sptpro_title_heading_tag . '>' : '';
			$tabs_aria_controls_for_id = 'tab-' . $post_id . $sptpro_data_count;
			$name_url                  = preg_replace( '/\s+/', '-', sanitize_title( get_the_title( get_the_ID() ) ) );
			$tab_name_url              = apply_filters( 'sp_tabs_name_slug', false );
			$tabs_aria_controls_for_id = $tab_name_url ? strtolower( $name_url ) : $tabs_aria_controls_for_id;

			include WP_TABS_PRO_PATH . '/public/partials/post-meta.php';

			echo '<li class="sp-tab__nav-item" role="tab" >';

			echo '<label class="sp-tab__nav-link ' . esc_attr( $sptpro_active_class ) . '" data-sptoggle="tab" for="#' . esc_attr( $tabs_aria_controls_for_id ) . '"  aria-controls="' . esc_attr( $tabs_aria_controls_for_id ) . '" aria-selected="true" tabindex="0">' . wp_kses_post( $tabs_content_title ) . $post_meta_after_title . '</label>'; // phpcs:ignore

			echo '</li>';

			++$sptpro_data_count;
		}
	}

	echo '</ul>
		<div class="sp-tab__tab-content">';

	// Second loop.
	$sptpro_cont_count = 1;
	if ( $post_query->have_posts() ) {

		while ( $post_query->have_posts() ) {
				$post_query->the_post();
			$sptpro_active_class   = $sptpro_tab_opened == $sptpro_cont_count ? 'sp-tab__show sp-tab__active' : ''; // phpcs:ignore
			$tabs_pane_variable_id = 'tab-' . $post_id . $sptpro_cont_count;
			$name_url              = preg_replace( '/\s+/', '-', sanitize_title( get_the_title( get_the_ID() ) ) );
			$tab_name_url          = apply_filters( 'sp_tabs_name_slug', false );
			$tabs_pane_variable_id = $tab_name_url ? strtolower( $name_url ) : $tabs_pane_variable_id;
			global $wp_embed;
			$sptpro_content = do_shortcode( $wp_embed->autoembed( get_the_content() ) );
			if ( function_exists( 'do_blocks' ) ) {
				$sptpro_content = do_blocks( $sptpro_content );
			}
			$sptpro_content_ptag = wpautop( trim( preg_replace( '/<!--(.|s)*?-->/', '', $sptpro_content ) ) );
			$animation_name      = $sptpro_tabs_animation ? 'animated ' . $sptpro_tabs_animation_type : '';
			$smooth_scrollbar    = ( 'custom' === $sptpro_fixed_height ) ? ' data-scrollbar style="overflow: hidden"' : '';
			include WP_TABS_PRO_PATH . '/public/partials/post-meta.php';
			include WP_TABS_PRO_PATH . '/public/partials/feature-image.php';

			echo '';
			echo sprintf(
				'<div class="sp-tab__tab-pane %1$s" id="%2$s" role="tabpanel" aria-hidden="false" %5$s>
					<div class="sp-tab__tab-body %4$s">%6$s <div class="sp-tab__tab-content">%7$s %3$s</div></div>
				</div>',
				esc_attr( $sptpro_active_class ),
				esc_attr( $tabs_pane_variable_id ),
				$sptpro_content_ptag, // phpcs:ignore
				esc_attr( $animation_name ),
				esc_attr( $smooth_scrollbar ),
				wp_kses( $post_thumb, $allow_meta_tag ),
				$post_meta_before_descriptions // phpcs:ignore
			);
			++$sptpro_cont_count;
		}
		wp_reset_postdata();
	}
}

echo '</div>
		</div>';
